@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 #
@@ -171,7 +171,7 @@ class SourceStat(object):
         @param key the key to be incremented
         @param value the increment (int)
         """
-        for counterId, level, row in self.active:
+        for counterId, _level, _row in self.active:
             counters = self.counters.setdefault(counterId, {})
             counters[key] = counters.setdefault(key, 0) + value
 
