@@ -110,6 +110,8 @@ class DebugBase(object):
         # Use it like this:
         # if hasattr(sys, 'breakpoint): sys.breakpoint()
         sys.breakpoint = self.set_trace
+        if sys.version_info[:2] >= (3, 7):
+            sys.breakpointhook = self.set_trace
 
     def __eventPollTimer(self):
         """
@@ -585,7 +587,7 @@ class DebugBase(object):
                 return frame.f_code.co_filename
             
             absFilename = os.path.abspath(fn)
-            if absFilename.endswith(('.pyc', '.pyo')):
+            if absFilename.endswith(('.pyc', '.pyo', '.pyd')):
                 fixedName = absFilename[:-1]
                 if not os.path.exists(fixedName):
                     fixedName = absFilename
