@@ -62,7 +62,7 @@ class E5GenericDiffHighlighter(QSyntaxHighlighter):
         @param rules set of highlighting rules (list of tuples of rule
             pattern (string) and highlighting format (QTextCharFormat))
         """
-        for idx, ruleFormat in enumerate(rules):
+        for _idx, ruleFormat in enumerate(rules):
             rule, formats = ruleFormat
             terminal = rule.startswith(TERMINAL(''))
             if terminal:
