@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -96,7 +96,7 @@ class MultiProjectReader(XMLStreamReaderBase):
                 if 'category' not in project:
                     # upgrade from 4.2 format
                     project["category"] = ""
-                self.multiProject.projects.append(project)
+                self.multiProject.addProject(project)
                 break
             
             if self.isStartElement():
