@@ -19,7 +19,7 @@ class ProjectReader(XMLStreamReaderBase):
     """
     Class for reading an XML project file.
     """
-    supportedVersions = ["4.6", "5.0", "5.1", "6.0"]
+    supportedVersions = ["4.6", "5.0", "5.1", "6.0", "6.1", "6.2"]
     
     def __init__(self, device, project):
         """
@@ -112,6 +112,12 @@ class ProjectReader(XMLStreamReaderBase):
                     self.__readFiletypeAssociations()
                 elif self.name() == "LexerAssociations":
                     self.__readLexerAssociations()
+                elif self.name() == "Make":
+                    self.__readBasicDataField(
+                        "Make", "MakeParameters", "MAKEPARAMS")
+                elif self.name() == "IdlCompiler":
+                    self.__readBasicDataField(
+                        "IdlCompiler", "IdlCompilerParameters", "IDLPARAMS")
                 elif self.name() == "ProjectTypeSpecific":
                     self.__readBasicDataField(
                         "ProjectTypeSpecific", "ProjectTypeSpecificData",
