@@ -108,7 +108,10 @@ def checkBlacklistedVersions():
     
     # check version of sip
     try:
-        import sip
+        try:
+            from PyQt5 import sip
+        except ImportError:
+            import sip
         sipVersion = sip.SIP_VERSION_STR
         # always assume, that snapshots are good
         if "snapshot" not in sipVersion:
@@ -301,50 +304,6 @@ def translate(*args):
     return QCoreApplication.translate(*args)
 
 
-###############################################################################
-## functions for searching a Python2/3 interpreter
-###############################################################################
-
-
-def findPythonInterpreters(pyVersion):
-    """
-    Module function for searching a Python interpreter.
-    
-    @param pyVersion major Python version
-    @return list of interpreters found (list of strings)
-    """
-    if pyVersion == 2:
-        winPathList = ["C:\\Python25", "C:\\Python26",
-                       "C:\\Python27", "C:\\Python28"]
-        posixVersionsList = ["2.5", "2.6", "2.7", "2.8"]
-    else:
-        winPathList = ["C:\\Python3{0}".format(x) for x in range(11)]
-        posixVersionsList = ["3.{0}".format(x) for x in range(11)]
-    posixPathList = ["/usr/bin", "/usr/local/bin"]
-    
-    interpreters = []
-    if isWindowsPlatform():
-        # search the interpreters on Windows platforms
-        for path in winPathList:
-            exeList = [
-                "python.exe",
-                "python{0}.{1}.exe".format(path[-2], path[-1]),
-            ]
-            for exe in exeList:
-                interpreter = os.path.join(path, exe)
-                if os.path.isfile(interpreter):
-                    interpreters.append(interpreter)
-    else:
-        # search interpreters on Posix and Mac platforms
-        for path in posixPathList:
-            for version in posixVersionsList:
-                interpreter = os.path.join(path, "python{0}".format(version))
-                if os.path.isfile(interpreter):
-                    interpreters.append(interpreter)
-    
-    return interpreters
-
-
 ###############################################################################
 ## functions for version handling
 ###############################################################################
