@@ -49,16 +49,18 @@ class FeedsDialog(QDialog, Ui_FeedsDialog):
             label.setText(feed[0])
             self.feedsLayout.addWidget(label, row, 0)
             self.feedsLayout.addWidget(button, row, 1)
-            button.clicked.connect(self.__addFeed)
+            button.clicked.connect(lambda: self.__addFeed(button))
         
         msh = self.minimumSizeHint()
         self.resize(max(self.width(), msh.width()), msh.height())
     
-    def __addFeed(self):
+    def __addFeed(self, button):
         """
         Private slot to add a RSS feed.
+        
+        @param button reference to the feed button
+        @type QPushButton
         """
-        button = self.sender()
         urlString = button.feed[1]
         url = QUrl(urlString)
         if not url.host():
