@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,6 +9,7 @@ Module implementing a dialog to select code style message codes.
 
 from __future__ import unicode_literals
 
+from PyQt5.QtCore import Qt
 from PyQt5.QtWidgets import QDialog, QTreeWidgetItem
 
 from .Ui_CodeStyleCodeSelectionDialog import Ui_CodeStyleCodeSelectionDialog
@@ -59,9 +60,12 @@ class CodeStyleCodeSelectionDialog(QDialog, Ui_CodeStyleCodeSelectionDialog):
                 itm.setIcon(0, UI.PixmapCache.getIcon("namingError.png"))
             elif code.startswith("D"):
                 itm.setIcon(0, UI.PixmapCache.getIcon("docstringError.png"))
+            itm.setFlags(itm.flags() | Qt.ItemIsUserCheckable)
             if code in codeList:
-                itm.setSelected(True)
+                itm.setCheckState(0, Qt.Checked)
                 codeList.remove(code)
+            else:
+                itm.setCheckState(0, Qt.Unchecked)
         self.codeTable.resizeColumnToContents(0)
         self.codeTable.resizeColumnToContents(1)
         self.codeTable.header().setStretchLastSection(True)
@@ -76,7 +80,9 @@ class CodeStyleCodeSelectionDialog(QDialog, Ui_CodeStyleCodeSelectionDialog):
         """
         selectedCodes = []
         
-        for itm in self.codeTable.selectedItems():
-            selectedCodes.append(itm.text(0))
+        for index in range(self.codeTable.topLevelItemCount()):
+            itm = self.codeTable.topLevelItem(index)
+            if itm.checkState(0) == Qt.Checked:
+                selectedCodes.append(itm.text(0))
         
         return ", ".join(self.__extraCodes + selectedCodes)
