@@ -508,7 +508,7 @@ class DocStyleChecker(object):
         @param source source to parse (list of string)
         @return context of extracted docstring (DocStyleContext)
         """
-        for kind, value, (line, char), _, _ in tokenize.generate_tokens(
+        for kind, value, (line, _char), _, _ in tokenize.generate_tokens(
                 StringIO("".join(source)).readline):
             if kind in [tokenize.COMMENT, tokenize.NEWLINE, tokenize.NL]:
                 continue
@@ -698,6 +698,11 @@ class DocStyleChecker(object):
         if (not docstring or not docstring.strip() or
                 not docstring.strip('\'"')):
             self.__error(context.start(), 0, "D101")
+        
+        if self.__docType == "eric" and \
+           docstring.strip('\'"').strip() == "Module documentation goes here.":
+            self.__error(docstringContext.end(), 0, "D201")
+            return
     
     def __checkFunctionDocstring(self, docstringContext, context):
         """
@@ -724,6 +729,12 @@ class DocStyleChecker(object):
         if (not docstring or not docstring.strip() or
                 not docstring.strip('\'"')):
             self.__error(context.start(), 0, code)
+        
+        if self.__docType == "eric" and \
+           docstring.strip('\'"').strip() == \
+                "Function documentation goes here.":
+            self.__error(docstringContext.end(), 0, "D202")
+            return
     
     def __checkClassDocstring(self, docstringContext, context):
         """
@@ -754,7 +765,7 @@ class DocStyleChecker(object):
         
         if self.__docType == "eric" and \
            docstring.strip('\'"').strip() == "Class documentation goes here.":
-            self.__error(context.start(), 0, "D206")
+            self.__error(docstringContext.end(), 0, "D206")
             return
     
     def __checkTripleDoubleQuotes(self, docstringContext, context):
