@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2003 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2003 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -368,9 +368,9 @@ class TabnannyDialog(QDialog, Ui_TabnannyDialog):
         filterList = [f.strip() for f in filterString.split(",")
                       if f.strip()]
         if filterList:
-            for filter in filterList:
+            for fileFilter in filterList:
                 fileList = \
-                    [f for f in fileList if not fnmatch.fnmatch(f, filter)]
+                    [f for f in fileList if not fnmatch.fnmatch(f, fileFilter)]
         
         self.resultList.clear()
         self.noResults = True
