@@ -41,16 +41,20 @@ class PipListDialog(QDialog, Ui_PipListDialog):
     ShowProcessEntryPointsMode = 2
     ShowProcessFilesListMode = 3
     
-    def __init__(self, pip, mode, plugin, title, parent=None):
+    def __init__(self, pip, mode, indexUrl, title, parent=None):
         """
         Constructor
         
-        @param pip reference to the master object (Pip)
-        @param mode list command mode (string; one of 'list',
-            'uptodate', 'outdated')
-        @param plugin reference to the plugin object (ToolPipPlugin)
-        @param title title of the dialog (string)
-        @param parent reference to the parent widget (QWidget)
+        @param pip reference to the master object
+        @type Pip
+        @param mode list command mode (one of 'list', 'uptodate', 'outdated')
+        @type str
+        @param indexUrl URL of the pypi index
+        @type str
+        @param title title of the dialog
+        @type str
+        @param parent reference to the parent widget
+        @type QWidget
         """
         assert mode in PipListDialog.CommandArguments
         
@@ -79,8 +83,8 @@ class PipListDialog(QDialog, Ui_PipListDialog):
         
         self.__pip = pip
         self.__mode = mode
-        self.__defaultCommand = plugin.getPreferences("CurrentPipExecutable")
         self.__ioEncoding = Preferences.getSystem("IOEncoding")
+        self.__indexUrl = indexUrl
         self.__errors = ""
         self.__output = []
         
@@ -90,10 +94,8 @@ class PipListDialog(QDialog, Ui_PipListDialog):
             "outdated": self.tr("All packages up-to-date"),
         }
         
-        self.__default = self.tr("<Default>")
-        pipExecutables = sorted(plugin.getPreferences("PipExecutables"))
-        self.pipComboBox.addItem(self.__default)
-        self.pipComboBox.addItems(pipExecutables)
+        self.venvComboBox.addItem(self.__pip.getDefaultEnvironmentString())
+        self.venvComboBox.addItems(self.__pip.getVirtualenvNames())
         
         if mode == "list":
             self.infoLabel.setText(self.tr("Installed Packages:"))
@@ -159,7 +161,8 @@ class PipListDialog(QDialog, Ui_PipListDialog):
         """
         Protected slot implementing a close event handler.
         
-        @param e close event (QCloseEvent)
+        @param e close event
+        @type QCloseEvent
         """
         self.__stopProcess()
         e.accept()
@@ -187,7 +190,7 @@ class PipListDialog(QDialog, Ui_PipListDialog):
                 E5MessageBox.critical(
                     self,
                     self.windowTitle(),
-                    self.tr("""<p>The pip command failed.</p>"""
+                    self.tr("""<p>The command failed.</p>"""
                             """<p>Reason: {0}</p>""").format(
                         self.__errors.replace("\r\n", "<br/>")
                             .replace("\n", "<br/>").replace("\r", "<br/>")
@@ -210,7 +213,8 @@ class PipListDialog(QDialog, Ui_PipListDialog):
         """
         Private slot called by a button of the button box clicked.
         
-        @param button button that was clicked (QAbstractButton)
+        @param button button that was clicked
+        @type QAbstractButton
         """
         if button == self.buttonBox.button(QDialogButtonBox.Close):
             self.close()
@@ -229,8 +233,10 @@ class PipListDialog(QDialog, Ui_PipListDialog):
         """
         Private slot connected to the finished signal.
         
-        @param exitCode exit code of the process (integer)
-        @param exitStatus exit status of the process (QProcess.ExitStatus)
+        @param exitCode exit code of the process
+        @type int
+        @param exitStatus exit status of the process
+        @type QProcess.ExitStatus
         """
         self.__finish()
     
@@ -260,17 +266,24 @@ class PipListDialog(QDialog, Ui_PipListDialog):
         QApplication.setOverrideCursor(Qt.WaitCursor)
         QApplication.processEvents()
         
-        command = self.pipComboBox.currentText()
-        if command == self.__default:
-            command = self.__defaultCommand
+        venvName = self.venvComboBox.currentText()
+        interpreter = self.__pip.getVirtualenvInterpreter(venvName)
+        if not interpreter:
+            return
         
-        args = PipListDialog.CommandArguments[self.__mode][:]
+        args = ["-m", "pip"] + PipListDialog.CommandArguments[self.__mode]
         if self.localCheckBox.isChecked():
             args.append("--local")
         if self.notRequiredCheckBox.isChecked():
             args.append("--not-required")
+        if self.userCheckBox.isChecked():
+            args.append("--user")
         
-        self.process.start(command, args)
+        if self.__indexUrl:
+            args.append("--index-url")
+            args.append(self.__indexUrl + "/simple")
+        
+        self.process.start(interpreter, args)
         procStarted = self.process.waitForStarted(5000)
         if not procStarted:
             self.buttonBox.setFocus()
@@ -280,7 +293,7 @@ class PipListDialog(QDialog, Ui_PipListDialog):
                 self.tr('Process Generation Error'),
                 self.tr(
                     'The process {0} could not be started.'
-                ).format(command))
+                ).format(interpreter))
             self.__finish()
     
     def __processOutput(self):
@@ -288,18 +301,23 @@ class PipListDialog(QDialog, Ui_PipListDialog):
         Private method to process the captured output.
         """
         if self.__output:
-            packageData = json.loads("\n".join(self.__output))
-            for package in packageData:
-                data = [
-                    package["name"],
-                    package["version"],
-                ]
-                if self.__mode == "outdated":
-                    data.extend([
-                        package["latest_version"],
-                        package["latest_filetype"],
-                    ])
-                QTreeWidgetItem(self.packageList, data)
+            try:
+                packageData = json.loads("\n".join(self.__output))
+                for package in packageData:
+                    data = [
+                        package["name"],
+                        package["version"],
+                    ]
+                    if self.__mode == "outdated":
+                        data.extend([
+                            package["latest_version"],
+                            package["latest_filetype"],
+                        ])
+                    QTreeWidgetItem(self.packageList, data)
+            except ValueError as err:
+                self.__errors += str(err) + "\n"
+                self.__errors += "received output:\n"
+                self.__errors += "\n".join(self.__output)
     
     def __readStdout(self):
         """
@@ -326,11 +344,12 @@ class PipListDialog(QDialog, Ui_PipListDialog):
                              self.__ioEncoding, 'replace')
     
     @pyqtSlot(str)
-    def on_pipComboBox_activated(self, txt):
+    def on_venvComboBox_activated(self, txt):
         """
-        Private slot handling the selection of a pip executable.
+        Private slot handling the selection of a virtual environment.
         
-        @param txt path of the pip executable (string)
+        @param txt virtual environment
+        @type str
         """
         self.__refresh()
     
@@ -339,7 +358,8 @@ class PipListDialog(QDialog, Ui_PipListDialog):
         """
         Private slot handling the switching of the local mode.
         
-        @param checked state of the local check box (boolean)
+        @param checked state of the local check box
+        @type bool
         """
         self.__refresh()
     
@@ -348,7 +368,18 @@ class PipListDialog(QDialog, Ui_PipListDialog):
         """
         Private slot handling the switching of the 'not required' mode.
         
-        @param checked state of the 'not required' check box (boolean)
+        @param checked state of the 'not required' check box
+        @type bool
+        """
+        self.__refresh()
+    
+    @pyqtSlot(bool)
+    def on_userCheckBox_clicked(self, checked):
+        """
+        Private slot handling the switching of the 'user-site' mode.
+        
+        @param checked state of the 'user-site' check box
+        @type bool
         """
         self.__refresh()
     
@@ -362,19 +393,20 @@ class PipListDialog(QDialog, Ui_PipListDialog):
         if len(self.packageList.selectedItems()) == 1:
             itm = self.packageList.selectedItems()[0]
             
-            command = self.pipComboBox.currentText()
-            if command == self.__default:
-                command = ""
+            environment = self.venvComboBox.currentText()
+            interpreter = self.__pip.getVirtualenvInterpreter(environment)
+            if not interpreter:
+                return
             
             QApplication.setOverrideCursor(Qt.WaitCursor)
             
-            args = ["show"]
+            args = ["-m", "pip", "show"]
             if self.verboseCheckBox.isChecked():
                 args.append("--verbose")
             if self.installedFilesCheckBox.isChecked():
                 args.append("--files")
             args.append(itm.text(0))
-            success, output = self.__pip.runProcess(args, cmd=command)
+            success, output = self.__pip.runProcess(args, interpreter)
             
             if success and output:
                 mode = PipListDialog.ShowProcessGeneralMode
@@ -477,14 +509,12 @@ class PipListDialog(QDialog, Ui_PipListDialog):
         """
         Private slot to upgrade pip itself.
         """
-        pip = self.pipComboBox.currentText()
-        if pip == self.__default:
-            pip = ""
-
-        res = self.__pip.upgradePip(pip=pip)
+        res = self.__pip.upgradePip(
+            venvName=self.venvComboBox.currentText(),
+            userSite=self.userCheckBox.isChecked())
         if res:
             self.__refresh()
-
+    
     def __executeUpgradePackages(self, packages):
         """
         Private method to execute the pip upgrade command.
@@ -492,12 +522,12 @@ class PipListDialog(QDialog, Ui_PipListDialog):
         @param packages list of package names to be upgraded
         @type list of str
         """
-        command = self.pipComboBox.currentText()
-        if command == self.__default:
-            command = ""
-
-        res = self.__pip.upgradePackages(packages, cmd=command)
+        res = self.__pip.upgradePackages(
+            packages, venvName=self.venvComboBox.currentText(),
+            userSite=self.userCheckBox.isChecked())
         if res:
+            self.activateWindow()
+            self.raise_()
             self.__refresh()
     
     def __uninstallPackages(self):
@@ -509,10 +539,10 @@ class PipListDialog(QDialog, Ui_PipListDialog):
             packages.append(itm.text(0))
         
         if packages:
-            command = self.pipComboBox.currentText()
-            if command == self.__default:
-                command = ""
-            
-            res = self.__pip.uninstallPackages(packages, cmd=command)
+            res = self.__pip.uninstallPackages(
+                packages,
+                venvName=self.venvComboBox.currentText())
             if res:
+                self.activateWindow()
+                self.raise_()
                 self.__refresh()
