@@ -16,8 +16,8 @@ except NameError:
 import os
 import collections
 
-from PyQt5.QtCore import pyqtSlot, qVersion, Qt, QDate, QProcess, QTimer, \
-    QRegExp, QSize, QPoint, QFileInfo
+from PyQt5.QtCore import pyqtSlot, Qt, QDate, QProcess, QTimer, QRegExp, \
+    QSize, QPoint, QFileInfo
 from PyQt5.QtGui import QCursor, QColor, QPixmap, QPainter, QPen, QIcon, \
     QTextCursor
 from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QHeaderView, \
@@ -26,6 +26,8 @@ from PyQt5.QtWidgets import QWidget, QDialogButtonBox, QHeaderView, \
 from E5Gui.E5Application import e5App
 from E5Gui import E5MessageBox, E5FileDialog
 
+from Globals import qVersionTuple
+
 from .Ui_GitLogBrowserDialog import Ui_GitLogBrowserDialog
 
 from .GitDiffHighlighter import GitDiffHighlighter
@@ -304,7 +306,7 @@ class GitLogBrowserDialog(QWidget, Ui_GitLogBrowserDialog):
         """
         self.__actionsMenu = QMenu()
         self.__actionsMenu.setTearOffEnabled(True)
-        if qVersion() >= "5.1.0":
+        if qVersionTuple() >= (5, 1, 0):
             self.__actionsMenu.setToolTipsVisible(True)
         else:
             self.__actionsMenu.hovered.connect(self.__actionsMenuHovered)
