@@ -28,7 +28,6 @@ from .GitUtilities import strToQByteArray
 import Preferences
 
 
-# TODO: add button to set user credentials (git remote set-url)
 class GitRemoteRepositoriesDialog(QWidget, Ui_GitRemoteRepositoriesDialog):
     """
     Class implementing a dialog to show available remote repositories.
@@ -307,9 +306,11 @@ class GitRemoteRepositoriesDialog(QWidget, Ui_GitRemoteRepositoriesDialog):
         enable = len(self.repolist.selectedItems()) == 1
         
         self.removeButton.setEnabled(enable)
-        self.renameButton.setEnabled(enable)
         self.pruneButton.setEnabled(enable)
         self.showInfoButton.setEnabled(enable)
+        self.renameButton.setEnabled(enable)
+        self.changeUrlButton.setEnabled(enable)
+        self.credentialsButton.setEnabled(enable)
     
     @pyqtSlot()
     def on_repolist_itemSelectionChanged(self):
@@ -326,15 +327,6 @@ class GitRemoteRepositoriesDialog(QWidget, Ui_GitRemoteRepositoriesDialog):
         self.vcs.gitAddRemote(self.projectDir)
         self.on_refreshButton_clicked()
     
-    @pyqtSlot()
-    def on_renameButton_clicked(self):
-        """
-        Private slot to rename a remote repository.
-        """
-        remoteName = self.repolist.selectedItems()[0].text(0)
-        self.vcs.gitRenameRemote(self.projectDir, remoteName)
-        self.on_refreshButton_clicked()
-    
     @pyqtSlot()
     def on_removeButton_clicked(self):
         """
@@ -359,3 +351,35 @@ class GitRemoteRepositoriesDialog(QWidget, Ui_GitRemoteRepositoriesDialog):
         """
         remoteName = self.repolist.selectedItems()[0].text(0)
         self.vcs.gitPruneRemote(self.projectDir, remoteName)
+    
+    @pyqtSlot()
+    def on_renameButton_clicked(self):
+        """
+        Private slot to rename a remote repository.
+        """
+        remoteName = self.repolist.selectedItems()[0].text(0)
+        self.vcs.gitRenameRemote(self.projectDir, remoteName)
+        self.on_refreshButton_clicked()
+    
+    @pyqtSlot()
+    def on_changeUrlButton_clicked(self):
+        """
+        Private slot to change the URL of a remote repository.
+        """
+        repositoryItem = self.repolist.selectedItems()[0]
+        remoteName = repositoryItem.text(0)
+        remoteUrl = repositoryItem.text(1)
+        self.vcs.gitChangeRemoteUrl(self.projectDir, remoteName, remoteUrl)
+        self.on_refreshButton_clicked()
+    
+    @pyqtSlot()
+    def on_credentialsButton_clicked(self):
+        """
+        Private slot to change the credentials of a remote repository.
+        """
+        repositoryItem = self.repolist.selectedItems()[0]
+        remoteName = repositoryItem.text(0)
+        remoteUrl = repositoryItem.text(1)
+        self.vcs.gitChangeRemoteCredentials(self.projectDir, remoteName,
+                                            remoteUrl)
+        self.on_refreshButton_clicked()
