@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -67,10 +67,10 @@ class HgBookmarkRenameDialog(QDialog, Ui_HgBookmarkRenameDialog):
         """
         Public method to retrieve the entered data.
         
-        @return tuple naming the new and old bookmark names
+        @return tuple naming the old and new bookmark names
             (string, string)
         """
         return (
+            self.bookmarkCombo.currentText().replace(" ", "_"),
             self.nameEdit.text().replace(" ", "_"),
-            self.bookmarkCombo.currentText().replace(" ", "_")
         )
