@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -26,6 +26,7 @@ from E5Gui import E5MessageBox
 from .Ui_HgBookmarksListDialog import Ui_HgBookmarksListDialog
 
 import UI.PixmapCache
+from Globals import strToQByteArray
 
 
 class HgBookmarksListDialog(QDialog, Ui_HgBookmarksListDialog):
@@ -346,7 +347,7 @@ class HgBookmarksListDialog(QDialog, Ui_HgBookmarksListDialog):
             self.errors.insertPlainText(inputTxt)
             self.errors.ensureCursorVisible()
         
-        self.process.write(inputTxt)
+        self.process.write(strToQByteArray(inputTxt))
         
         self.passwordCheckBox.setChecked(False)
         self.input.clear()
