@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -260,21 +260,6 @@ class HgProjectHelper(VcsProjectHelper):
         self.vcsExportAct.triggered.connect(self._vcsExport)
         self.actions.append(self.vcsExportAct)
         
-        self.vcsLogAct = E5Action(
-            self.tr('Show log'),
-            UI.PixmapCache.getIcon("vcsLog.png"),
-            self.tr('Show &log'),
-            0, 0, self, 'mercurial_log')
-        self.vcsLogAct.setStatusTip(self.tr(
-            'Show the log of the local project'
-        ))
-        self.vcsLogAct.setWhatsThis(self.tr(
-            """<b>Show log</b>"""
-            """<p>This shows the log of the local project.</p>"""
-        ))
-        self.vcsLogAct.triggered.connect(self._vcsLog)
-        self.actions.append(self.vcsLogAct)
-        
         self.hgLogBrowserAct = E5Action(
             self.tr('Show log browser'),
             UI.PixmapCache.getIcon("vcsLog.png"),
@@ -1444,7 +1429,6 @@ class HgProjectHelper(VcsProjectHelper):
         menu.addMenu(branchesMenu)
         menu.addMenu(bookmarksMenu)
         menu.addSeparator()
-        menu.addAction(self.vcsLogAct)
         menu.addAction(self.hgLogBrowserAct)
         menu.addSeparator()
         menu.addAction(self.vcsStatusAct)
@@ -1505,7 +1489,6 @@ class HgProjectHelper(VcsProjectHelper):
         toolbarManager.addAction(self.vcsCommitAct, title)
         toolbarManager.addAction(self.hgPushAct, title)
         toolbarManager.addAction(self.hgPushForcedAct, title)
-        toolbarManager.addAction(self.vcsLogAct, title)
         toolbarManager.addAction(self.hgExtDiffAct, title)
         toolbarManager.addAction(self.hgSummaryAct, title)
         toolbarManager.addAction(self.vcsRevertAct, title)
