@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2011 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2011 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -814,8 +814,8 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         self.vcs.getExtensionObject("mq")\
             .hgQueueShowHeader(self.project.getProjectPath())
     
-    def __hgQueuePushPopPatches(self, name, operation, all=False, named=False,
-                                force=False):
+    def __hgQueuePushPopPatches(self, name, operation, doAll=False,
+                                named=False, force=False):
         """
         Private method to push patches onto the stack or pop patches off the
         stack.
@@ -823,13 +823,13 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         @param name file/directory name (string)
         @param operation operation type to be performed (Queues.POP,
             Queues.PUSH, Queues.GOTO)
-        @keyparam all flag indicating to push/pop all (boolean)
+        @keyparam doAll flag indicating to push/pop all (boolean)
         @keyparam named flag indicating to push/pop until a named patch
             is at the top of the stack (boolean)
         @keyparam force flag indicating a forceful pop (boolean)
         """
         shouldReopen = self.vcs.getExtensionObject("mq")\
-            .hgQueuePushPopPatches(name, operation=operation, all=all,
+            .hgQueuePushPopPatches(name, operation=operation, doAll=doAll,
                                    named=named, force=force)
         if shouldReopen:
             res = E5MessageBox.yesNo(
@@ -846,7 +846,7 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         self.__hgQueuePushPopPatches(
             self.project.getProjectPath(),
-            operation=Queues.PUSH, all=False, named=False)
+            operation=Queues.PUSH, doAll=False, named=False)
     
     def __hgQueuePushPatchForced(self):
         """
@@ -855,7 +855,7 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         self.__hgQueuePushPopPatches(
             self.project.getProjectPath(),
-            operation=Queues.PUSH, all=False, named=False, force=True)
+            operation=Queues.PUSH, doAll=False, named=False, force=True)
     
     def __hgQueuePushAllPatches(self):
         """
@@ -863,7 +863,7 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         self.__hgQueuePushPopPatches(
             self.project.getProjectPath(),
-            operation=Queues.PUSH, all=True, named=False)
+            operation=Queues.PUSH, doAll=True, named=False)
     
     def __hgQueuePushAllPatchesForced(self):
         """
@@ -872,7 +872,7 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         self.__hgQueuePushPopPatches(
             self.project.getProjectPath(),
-            operation=Queues.PUSH, all=True, named=False, force=True)
+            operation=Queues.PUSH, doAll=True, named=False, force=True)
     
     def __hgQueuePushPatches(self):
         """
@@ -881,7 +881,7 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         self.__hgQueuePushPopPatches(
             self.project.getProjectPath(),
-            operation=Queues.PUSH, all=False, named=True)
+            operation=Queues.PUSH, doAll=False, named=True)
     
     def __hgQueuePushPatchesForced(self):
         """
@@ -890,7 +890,7 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         self.__hgQueuePushPopPatches(
             self.project.getProjectPath(),
-            operation=Queues.PUSH, all=False, named=True, force=True)
+            operation=Queues.PUSH, doAll=False, named=True, force=True)
     
     def __hgQueuePopPatch(self):
         """
@@ -898,7 +898,7 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         self.__hgQueuePushPopPatches(
             self.project.getProjectPath(),
-            operation=Queues.POP, all=False, named=False)
+            operation=Queues.POP, doAll=False, named=False)
     
     def __hgQueuePopPatchForced(self):
         """
@@ -907,7 +907,7 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         self.__hgQueuePushPopPatches(
             self.project.getProjectPath(),
-            operation=Queues.POP, all=False, named=False, force=True)
+            operation=Queues.POP, doAll=False, named=False, force=True)
     
     def __hgQueuePopAllPatches(self):
         """
@@ -915,7 +915,7 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         self.__hgQueuePushPopPatches(
             self.project.getProjectPath(),
-            operation=Queues.POP, all=True, named=False)
+            operation=Queues.POP, doAll=True, named=False)
     
     def __hgQueuePopAllPatchesForced(self):
         """
@@ -924,7 +924,7 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         self.__hgQueuePushPopPatches(
             self.project.getProjectPath(),
-            operation=Queues.POP, all=True, named=False, force=True)
+            operation=Queues.POP, doAll=True, named=False, force=True)
     
     def __hgQueuePopPatches(self):
         """
@@ -933,7 +933,7 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         self.__hgQueuePushPopPatches(
             self.project.getProjectPath(),
-            operation=Queues.POP, all=False, named=True)
+            operation=Queues.POP, doAll=False, named=True)
     
     def __hgQueuePopPatchesForced(self):
         """
@@ -942,7 +942,7 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         self.__hgQueuePushPopPatches(
             self.project.getProjectPath(),
-            operation=Queues.POP, all=False, named=True, force=True)
+            operation=Queues.POP, doAll=False, named=True, force=True)
     
     def __hgQueueGotoPatch(self):
         """
@@ -951,7 +951,7 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         self.__hgQueuePushPopPatches(
             self.project.getProjectPath(),
-            operation=Queues.GOTO, all=False, named=True)
+            operation=Queues.GOTO, doAll=False, named=True)
     
     def __hgQueueGotoPatchForced(self):
         """
@@ -960,7 +960,7 @@ class QueuesProjectHelper(HgExtensionProjectHelper):
         """
         self.__hgQueuePushPopPatches(
             self.project.getProjectPath(),
-            operation=Queues.GOTO, all=False, named=True, force=True)
+            operation=Queues.GOTO, doAll=False, named=True, force=True)
     
     def __hgQueueListPatches(self):
         """
