@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2005 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2005 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -96,21 +96,6 @@ class SvnProjectHelper(VcsProjectHelper):
         self.vcsCommitAct.triggered.connect(self._vcsCommit)
         self.actions.append(self.vcsCommitAct)
         
-        self.vcsLogAct = E5Action(
-            self.tr('Show log'),
-            UI.PixmapCache.getIcon("vcsLog.png"),
-            self.tr('Show &log'),
-            0, 0, self, 'subversion_log')
-        self.vcsLogAct.setStatusTip(self.tr(
-            'Show the log of the local project'
-        ))
-        self.vcsLogAct.setWhatsThis(self.tr(
-            """<b>Show log</b>"""
-            """<p>This shows the log of the local project.</p>"""
-        ))
-        self.vcsLogAct.triggered.connect(self._vcsLog)
-        self.actions.append(self.vcsLogAct)
-        
         self.svnLogBrowserAct = E5Action(
             self.tr('Show log browser'),
             UI.PixmapCache.getIcon("vcsLog.png"),
@@ -511,7 +496,6 @@ class SvnProjectHelper(VcsProjectHelper):
         else:
             menu.addAction(self.svnListAct)
         menu.addSeparator()
-        menu.addAction(self.vcsLogAct)
         menu.addAction(self.svnLogBrowserAct)
         menu.addSeparator()
         menu.addAction(self.vcsStatusAct)
@@ -572,7 +556,6 @@ class SvnProjectHelper(VcsProjectHelper):
         toolbarManager.addToolBar(self.__toolbar, title)
         toolbarManager.addAction(self.vcsUpdateAct, title)
         toolbarManager.addAction(self.vcsCommitAct, title)
-        toolbarManager.addAction(self.vcsLogAct, title)
         toolbarManager.addAction(self.svnExtDiffAct, title)
         toolbarManager.addAction(self.svnUrlDiffAct, title)
         toolbarManager.addAction(self.svnChangeListsAct, title)
