@@ -127,7 +127,7 @@ class PyRegExpWizardWidget(QWidget, Ui_PyRegExpWizardDialog):
                 steps = abs(steps)
             else:
                 act = QTextCursor.Right
-            for i in range(steps):
+            for _ in range(steps):
                 tc.movePosition(act)
         self.regexpTextEdit.setTextCursor(tc)
         
