@@ -448,8 +448,10 @@ class QRegExpWizardCharactersDialog(QDialog, Ui_QRegExpWizardCharactersDialog):
         cb2a.hide()
         self.singlesItemsBoxLayout.addWidget(hbox)
         
-        cb1.activated[int].connect(self.__singlesCharTypeSelected)
-        cb2.activated[int].connect(self.__singlesCharTypeSelected)
+        cb1.activated[int].connect(
+            lambda i: self.__singlesCharTypeSelected(i, cb1))
+        cb2.activated[int].connect(
+            lambda i: self.__singlesCharTypeSelected(i, cb2))
         hbox.show()
         
         self.singlesItemsBox.adjustSize()
@@ -482,7 +484,9 @@ class QRegExpWizardCharactersDialog(QDialog, Ui_QRegExpWizardCharactersDialog):
         hboxLayout.addWidget(le2)
         self.rangesItemsBoxLayout.addWidget(hbox)
         
-        cb1.activated[int].connect(self.__rangesCharTypeSelected)
+        cb1.activated[int].connect(
+            lambda i: self.__rangesCharTypeSelected(i, cb1))
+        
         hbox.show()
         
         self.rangesItemsBox.adjustSize()
@@ -547,14 +551,16 @@ class QRegExpWizardCharactersDialog(QDialog, Ui_QRegExpWizardCharactersDialog):
                 combo.hide()
         lineedit.clear()
         
-    def __singlesCharTypeSelected(self, index):
+    def __singlesCharTypeSelected(self, index, combo):
         """
         Private slot to handle the activated(int) signal of the single chars
         combo boxes.
         
-        @param index selected list index (integer)
+        @param index selected list index
+        @type int
+        @param combo reference to the combo box
+        @type QComboBox
         """
-        combo = self.sender()
         for entriesList in self.singlesEntries:
             if combo == entriesList[0]:
                 formatIdentifier = combo.itemData(index)
@@ -562,14 +568,16 @@ class QRegExpWizardCharactersDialog(QDialog, Ui_QRegExpWizardCharactersDialog):
                     formatIdentifier, entriesList[1], entriesList[2])
                 break
         
-    def __rangesCharTypeSelected(self, index):
+    def __rangesCharTypeSelected(self, index, combo):
         """
         Private slot to handle the activated(int) signal of the char ranges
         combo boxes.
         
-        @param index selected list index (integer)
+        @param index selected list index
+        @type int
+        @param combo reference to the combo box
+        @type QComboBox
         """
-        combo = self.sender()
         for entriesList in self.rangesEntries:
             if combo == entriesList[0]:
                 formatIdentifier = combo.itemData(index)
