@@ -199,7 +199,7 @@ class QRegularExpressionWizardWidget(QWidget,
                 steps = abs(steps)
             else:
                 act = QTextCursor.Right
-            for i in range(steps):
+            for _ in range(steps):
                 tc.movePosition(act)
         self.regexpTextEdit.setTextCursor(tc)
     
