@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -45,6 +45,11 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
         
         self.defaultEncodingComboBox.addItems(sorted(supportedCodecs))
         
+        self.previewMarkdownHTMLFormatComboBox.addItems(
+            ["XHTML1", "HTML4", "HTML5"])
+        self.previewRestDocutilsHTMLFormatComboBox.addItems(
+            ["HTML4", "HTML5"])
+        
         # set initial values
         self.autosaveSlider.setValue(
             Preferences.getEditor("AutosaveInterval"))
@@ -71,6 +76,8 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
                 Preferences.getEditor("DefaultSaveFilter")))
         self.automaticEolConversionCheckBox.setChecked(
             Preferences.getEditor("AutomaticEOLConversion"))
+        self.insertFinalNewlineCheckBox.setChecked(
+            Preferences.getEditor("InsertFinalNewline"))
         
         eolMode = Preferences.getEditor("EOLMode")
         if eolMode == QsciScintilla.EolWindows:
@@ -91,6 +98,14 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
             " ".join(Preferences.getEditor("PreviewQssFileNameExtensions")))
         self.previewRestSphinxCheckBox.setChecked(
             Preferences.getEditor("PreviewRestUseSphinx"))
+        self.previewMarkdownNLtoBreakCheckBox.setChecked(
+            Preferences.getEditor("PreviewMarkdownNLtoBR"))
+        index = self.previewMarkdownHTMLFormatComboBox.findText(
+            Preferences.getEditor("PreviewMarkdownHTMLFormat"))
+        self.previewMarkdownHTMLFormatComboBox.setCurrentIndex(index)
+        index = self.previewRestDocutilsHTMLFormatComboBox.findText(
+            Preferences.getEditor("PreviewRestDocutilsHTMLFormat"))
+        self.previewRestDocutilsHTMLFormatComboBox.setCurrentIndex(index)
         
     def save(self):
         """
@@ -130,6 +145,9 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
         Preferences.setEditor(
             "AutomaticEOLConversion",
             self.automaticEolConversionCheckBox.isChecked())
+        Preferences.setEditor(
+            "InsertFinalNewline",
+            self.insertFinalNewlineCheckBox.isChecked())
         
         if self.crlfRadioButton.isChecked():
             Preferences.setEditor("EOLMode", QsciScintilla.EolWindows)
@@ -161,6 +179,15 @@ class EditorFilePage(ConfigurationPageBase, Ui_EditorFilePage):
         Preferences.setEditor(
             "PreviewRestUseSphinx",
             self.previewRestSphinxCheckBox.isChecked())
+        Preferences.setEditor(
+            "PreviewMarkdownNLtoBR",
+            self.previewMarkdownNLtoBreakCheckBox.isChecked())
+        Preferences.setEditor(
+            "PreviewMarkdownHTMLFormat",
+            self.previewMarkdownHTMLFormatComboBox.currentText())
+        Preferences.setEditor(
+            "PreviewRestDocutilsHTMLFormat",
+            self.previewRestDocutilsHTMLFormatComboBox.currentText())
     
     def __setDefaultFiltersLists(self, keepSelection=False):
         """
