@@ -21,11 +21,9 @@ class HelpVirusTotalPage(ConfigurationPageBase, Ui_HelpVirusTotalPage):
     """
     Class implementing VirusTotal configuration page (help viewer variant).
     """
-    def __init__(self, parent=None):
+    def __init__(self):
         """
         Constructor
-        
-        @param parent reference to the parent widget (QWidget)
         """
         super(HelpVirusTotalPage, self).__init__()
         self.setupUi(self)
@@ -113,5 +111,5 @@ def create(dlg):
     @param dlg reference to the configuration dialog
     @return reference to the instantiated page (ConfigurationPageBase)
     """
-    page = HelpVirusTotalPage(dlg)
+    page = HelpVirusTotalPage()
     return page
