@@ -23,11 +23,9 @@ class MimeTypesPage(ConfigurationPageBase, Ui_MimeTypesPage):
     """
     Class implementing the Text Mime Types configuration page.
     """
-    def __init__(self, parent=None):
+    def __init__(self):
         """
         Constructor
-        
-        @param parent reference to the parent widget (QWidget)
         """
         super(MimeTypesPage, self).__init__()
         self.setupUi(self)
