@@ -20,11 +20,9 @@ class TrayStarterPage(ConfigurationPageBase, Ui_TrayStarterPage):
     """
     Class implementing the tray starter configuration page.
     """
-    def __init__(self, parent=None):
+    def __init__(self):
         """
         Constructor
-        
-        @param parent reference to the parent widget (QWidget)
         """
         super(TrayStarterPage, self).__init__()
         self.setupUi(self)
