@@ -95,6 +95,12 @@ class WebBrowserAppearancePage(ConfigurationPageBase,
         self.warnOnMultipleCloseCheckBox.setChecked(
             Preferences.getWebBrowser("WarnOnMultipleClose"))
         
+        try:
+            # Qt 5.10
+            self.scrollbarsCheckBox.setChecked(
+                Preferences.getWebBrowser("ShowScrollBars"))
+        except KeyError:
+            self.scrollbarsCheckBox.setEnabled(False)
         self.toolbarsCheckBox.setChecked(
             Preferences.getWebBrowser("ShowToolbars"))
     
@@ -177,6 +183,11 @@ class WebBrowserAppearancePage(ConfigurationPageBase,
             "WarnOnMultipleClose",
             self.warnOnMultipleCloseCheckBox.isChecked())
         
+        if self.scrollbarsCheckBox.isEnabled():
+            Preferences.setWebBrowser(
+                "ShowScrollBars",
+                self.scrollbarsCheckBox.isChecked())
+        
         Preferences.setWebBrowser(
             "ShowToolbars",
             self.toolbarsCheckBox.isChecked())
