@@ -14,6 +14,8 @@ from PyQt5.QtCore import pyqtSlot, QLocale
 from .ConfigurationPageBase import ConfigurationPageBase
 from .Ui_WebBrowserPage import Ui_WebBrowserPage
 
+from Globals import qVersionTuple
+
 import UI.PixmapCache
 import Preferences
 
@@ -73,6 +75,15 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
         except KeyError:
             self.screenCaptureCheckBox.setEnabled(False)
             self.webGLCheckBox.setEnabled(False)
+        try:
+            # Qt 5.11
+            self.autoplayMediaCheckBox.setChecked(
+                Preferences.getWebBrowser("PlaybackRequiresUserGesture"))
+            self.webRtcPublicOnlyCheckBox.setChecked(
+                Preferences.getWebBrowser("WebRTCPublicInterfacesOnly"))
+        except KeyError:
+            self.autoplayMediaCheckBox.setEnabled(False)
+            self.webRtcPublicOnlyCheckBox.setEnabled(False)
         
         self.javaScriptGroup.setChecked(
             Preferences.getWebBrowser("JavaScriptEnabled"))
@@ -87,6 +98,12 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
             self.jsActivateWindowsCheckBox.setEnabled(False)
         self.jsClipboardCheckBox.setChecked(
             Preferences.getWebBrowser("JavaScriptCanAccessClipboard"))
+        try:
+            # Qt 5.11
+            self.jsPasteCheckBox.setChecked(
+                Preferences.getWebBrowser("JavaScriptCanPaste"))
+        except KeyError:
+            self.jsPasteCheckBox.setEnabled(False)
         self.pluginsCheckBox.setChecked(
             Preferences.getWebBrowser("PluginsEnabled"))
         self.doNotTrackCheckBox.setChecked(
@@ -205,10 +222,22 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
         self.autoScrollDividerSpinBox.setValue(
             Preferences.getWebBrowser("AutoScrollDivider"))
         
-        self.webInspectorGroup.setChecked(
-            Preferences.getWebBrowser("WebInspectorEnabled"))
-        self.webInspectorPortSpinBox.setValue(
-            Preferences.getWebBrowser("WebInspectorPort"))
+        if qVersionTuple() < (5, 11, 0):
+            self.webInspectorGroup.setChecked(
+                Preferences.getWebBrowser("WebInspectorEnabled"))
+            self.webInspectorPortSpinBox.setValue(
+                Preferences.getWebBrowser("WebInspectorPort"))
+        else:
+            self.webInspectorGroup.setEnabled(False)
+        
+        if qVersionTuple() >= (5, 11, 0):
+            self.protocolHandlerComboBox.setCurrentIndex(
+                Preferences.getWebBrowser("AcceptProtocolHandlerRequest"))
+            self.requestQuotaComboBox.setCurrentIndex(
+                Preferences.getWebBrowser("AcceptQuotaRequest"))
+        else:
+            self.protocolHandlerComboBox.setEnabled(False)
+            self.requestQuotaComboBox.setEnabled(False)
     
     def save(self):
         """
@@ -244,6 +273,14 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
                 "WebGLEnabled",
                 self.webGLCheckBox.isChecked())
         
+        if self.autoplayMediaCheckBox.isEnabled():
+            Preferences.setWebBrowser(
+                "PlaybackRequiresUserGesture",
+                self.autoplayMediaCheckBox.isChecked())
+            Preferences.setWebBrowser(
+                "WebRTCPublicInterfacesOnly",
+                self.webRtcPublicOnlyCheckBox.isChecked())
+        
         Preferences.setWebBrowser(
             "JavaScriptEnabled",
             self.javaScriptGroup.isChecked())
@@ -257,6 +294,10 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
         Preferences.setWebBrowser(
             "JavaScriptCanAccessClipboard",
             self.jsClipboardCheckBox.isChecked())
+        if self.jsPasteCheckBox.isEnabled():
+            Preferences.setWebBrowser(
+                "JavaScriptCanPaste",
+                self.jsPasteCheckBox.isChecked())
         Preferences.setWebBrowser(
             "PluginsEnabled",
             self.pluginsCheckBox.isChecked())
@@ -368,12 +409,21 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
             "AutoScrollDivider",
             self.autoScrollDividerSpinBox.value())
         
-        Preferences.setWebBrowser(
-            "WebInspectorEnabled",
-            self.webInspectorGroup.isChecked())
-        Preferences.setWebBrowser(
-            "WebInspectorPort",
-            self.webInspectorPortSpinBox.value())
+        if qVersionTuple() < (5, 11, 0):
+            Preferences.setWebBrowser(
+                "WebInspectorEnabled",
+                self.webInspectorGroup.isChecked())
+            Preferences.setWebBrowser(
+                "WebInspectorPort",
+                self.webInspectorPortSpinBox.value())
+        
+        if self.protocolHandlerComboBox.isEnabled():
+            Preferences.setWebBrowser(
+                "AcceptProtocolHandlerRequest",
+                self.protocolHandlerComboBox.currentIndex())
+            Preferences.setWebBrowser(
+                "AcceptQuotaRequest",
+                self.requestQuotaComboBox.currentIndex())
     
     @pyqtSlot()
     def on_setCurrentPageButton_clicked(self):
