@@ -169,21 +169,38 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
             Utilities.generatePyQtToolPath("pyrcc5"),
             '-version', '', -1, versionRe='Resource Compiler|pyrcc5')
         
-        # 3. do the PySide programs
-        # 3a. Translation Extractor PySide
+        # 3.1 do the PySide programs
+        # 3.1a. Translation Extractor PySide
         self.__createProgramEntry(
             self.tr("Translation Extractor (Python, PySide)"),
-            Utilities.generatePySideToolPath("pyside-lupdate"),
+            Utilities.generatePySideToolPath("pyside-lupdate", "1"),
             '-version', '', -1, versionRe='lupdate')
-        # 3b. Forms Compiler PySide
+        # 3.1b. Forms Compiler PySide
         self.__createProgramEntry(
             self.tr("Forms Compiler (Python, PySide)"),
-            Utilities.generatePySideToolPath("pyside-uic"),
+            Utilities.generatePySideToolPath("pyside-uic", "1"),
             '--version', 'PySide User', 5, versionCleanup=(0, -1))
-        # 3.c Resource Compiler PySide
+        # 3.1c Resource Compiler PySide
         self.__createProgramEntry(
             self.tr("Resource Compiler (Python, PySide)"),
-            Utilities.generatePySideToolPath("pyside-rcc"),
+            Utilities.generatePySideToolPath("pyside-rcc", "1"),
+            '-version', 'Resource Compiler', -1)
+        
+        # 3.2 do the PySide2 programs
+        # 3.2a. Translation Extractor PySide2
+        self.__createProgramEntry(
+            self.tr("Translation Extractor (Python, PySide2)"),
+            Utilities.generatePySideToolPath("pyside2-lupdate", "2"),
+            '-version', '', -1, versionRe='lupdate')
+        # 3.2b. Forms Compiler PySide2
+        self.__createProgramEntry(
+            self.tr("Forms Compiler (Python, PySide2)"),
+            Utilities.generatePySideToolPath("pyside2-uic", "2"),
+            '--version', 'PySide2 User', -1, versionCleanup=(0, -1))
+        # 3.2c Resource Compiler PySide2
+        self.__createProgramEntry(
+            self.tr("Resource Compiler (Python, PySide2)"),
+            Utilities.generatePySideToolPath("pyside2-rcc", "2"),
             '-version', 'Resource Compiler', -1)
         
         # 4. do the Ruby programs
@@ -263,6 +280,8 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
             if info["programEntry"]:
                 if "exeModule" not in info:
                     info["exeModule"] = None
+                if "versionRe" not in info:
+                    info["versionRe"] = None
                 self.__createProgramEntry(
                     info["header"],
                     info["exe"],
@@ -271,6 +290,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                     versionPosition=info["versionPosition"],
                     version=info["version"],
                     versionCleanup=info["versionCleanup"],
+                    versionRe=info["versionRe"],
                     exeModule=info["exeModule"],
                 )
             else:
@@ -345,23 +365,29 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                         output = str(proc.readAllStandardOutput(),
                                      Preferences.getSystem("IOEncoding"),
                                      'replace')
-                        if versionRe is None:
-                            versionRe = "^{0}".format(
-                                re.escape(versionStartsWith))
-                        versionRe = re.compile(versionRe, re.UNICODE)
-                        for line in output.splitlines():
-                            if versionRe.search(line):
-                                try:
-                                    version = line.split()[versionPosition]
-                                    if versionCleanup:
-                                        version = version[
-                                            versionCleanup[0]:versionCleanup[1]
-                                        ]
-                                    break
-                                except IndexError:
-                                    version = self.tr("(unknown)")
+                        if exeModule and exeModule[0] == "-m" and \
+                            ("ImportError:" in output or
+                             "ModuleNotFoundError:" in output):
+                            version = self.tr("(module not found)")
                         else:
-                            version = self.tr("(unknown)")
+                            if versionRe is None:
+                                versionRe = "^{0}".format(
+                                    re.escape(versionStartsWith))
+                            versionRe = re.compile(versionRe, re.UNICODE)
+                            for line in output.splitlines():
+                                if versionRe.search(line):
+                                    try:
+                                        version = line.split()[versionPosition]
+                                        if versionCleanup:
+                                            version = version[
+                                                versionCleanup[0]:
+                                                versionCleanup[1]
+                                            ]
+                                        break
+                                    except IndexError:
+                                        version = self.tr("(unknown)")
+                            else:
+                                version = self.tr("(unknown)")
                     else:
                         version = self.tr("(not executable)")
                 if exeModule:
