@@ -10,13 +10,13 @@ Module implementing a dialog for entering project specific debugger settings.
 from __future__ import unicode_literals
 
 import os
-import sys
 
 from PyQt5.QtCore import pyqtSlot
 from PyQt5.QtWidgets import QDialog, QComboBox
 
 from E5Gui.E5Completers import E5DirCompleter
 from E5Gui.E5PathPicker import E5PathPickerModes
+from E5Gui.E5Application import e5App
 
 from .Ui_DebuggerPropertiesDialog import Ui_DebuggerPropertiesDialog
 
@@ -55,30 +55,31 @@ class DebuggerPropertiesDialog(QDialog, Ui_DebuggerPropertiesDialog):
         self.debugClientClearHistoryButton.setIcon(
             UI.PixmapCache.getIcon("editDelete.png"))
         
-        interpreterHistory = Preferences.getProject(
-            "DebuggerInterpreterHistory")
-        self.interpreterPicker.setMode(E5PathPickerModes.OpenFileMode)
-        self.interpreterPicker.setInsertPolicy(QComboBox.InsertAtTop)
-        self.interpreterPicker.setSizeAdjustPolicy(
-            QComboBox.AdjustToMinimumContentsLength)
-        self.interpreterPicker.setPathsList(interpreterHistory)
-        self.interpreterClearHistoryButton.setIcon(
-            UI.PixmapCache.getIcon("editDelete.png"))
+        self.venvComboBox.addItem("")
+        self.venvComboBox.addItems(
+            sorted(e5App().getObject("VirtualEnvManager")
+                   .getVirtualenvNames()))
         
         self.translationLocalCompleter = E5DirCompleter(
             self.translationLocalEdit)
         
         self.project = project
         
-        if self.project.debugProperties["INTERPRETER"]:
-            self.interpreterPicker.setText(
-                self.project.debugProperties["INTERPRETER"])
+        if self.project.debugProperties["VIRTUALENV"]:
+            venvIndex = max(0, self.venvComboBox.findText(
+                self.project.debugProperties["VIRTUALENV"]))
         else:
-            if self.project.pdata["PROGLANGUAGE"] in \
-                    ["Python", "Python2", "Python3"]:
-                self.interpreterPicker.setText(sys.executable)
-            elif self.project.pdata["PROGLANGUAGE"] == "Ruby":
-                self.interpreterPicker.setText("/usr/bin/ruby")
+            if self.project.pdata["PROGLANGUAGE"] in ["Python", "Python2"]:
+                venvName = Preferences.getDebugger("Python2VirtualEnv")
+            elif self.project.pdata["PROGLANGUAGE"] == "Python3":
+                venvName = Preferences.getDebugger("Python3VirtualEnv")
+            else:
+                venvName = ""
+            if venvName:
+                venvIndex = max(0, self.venvComboBox.findText(venvName))
+            else:
+                venvIndex = 0
+        self.venvComboBox.setCurrentIndex(venvIndex)
         if self.project.debugProperties["DEBUGCLIENT"]:
             self.debugClientPicker.setText(
                 self.project.debugProperties["DEBUGCLIENT"])
@@ -134,14 +135,8 @@ class DebuggerPropertiesDialog(QDialog, Ui_DebuggerPropertiesDialog):
         """
         Public method to store the entered/modified data.
         """
-        self.project.debugProperties["INTERPRETER"] = \
-            self.interpreterPicker.text()
-        if not self.project.debugProperties["INTERPRETER"]:
-            if self.project.pdata["PROGLANGUAGE"] in \
-                    ["Python", "Python2", "Python3"]:
-                self.project.debugProperties["INTERPRETER"] = sys.executable
-            elif self.project.pdata["PROGLANGUAGE"] == "Ruby":
-                self.project.debugProperties["INTERPRETER"] = "/usr/bin/ruby"
+        self.project.debugProperties["VIRTUALENV"] = \
+            self.venvComboBox.currentText()
         
         self.project.debugProperties["DEBUGCLIENT"] = \
             self.debugClientPicker.text()
@@ -193,13 +188,6 @@ class DebuggerPropertiesDialog(QDialog, Ui_DebuggerPropertiesDialog):
             debugClientsHistory.insert(0, debugClient)
         Preferences.setProject("DebugClientsHistory",
                                debugClientsHistory)
-        
-        interpreter = self.interpreterPicker.text()
-        interpreterHistory = self.interpreterPicker.getPathItems()
-        if interpreter not in interpreterHistory:
-            interpreterHistory.insert(0, interpreter)
-        Preferences.setProject("DebuggerInterpreterHistory",
-                               interpreterHistory)
     
     @pyqtSlot()
     def on_debugClientClearHistoryButton_clicked(self):
@@ -208,13 +196,6 @@ class DebuggerPropertiesDialog(QDialog, Ui_DebuggerPropertiesDialog):
         """
         self.__clearHistory(self.debugClientPicker)
     
-    @pyqtSlot()
-    def on_interpreterClearHistoryButton_clicked(self):
-        """
-        Private slot to clear the interpreter history.
-        """
-        self.__clearHistory(self.interpreterPicker)
-    
     def __clearHistory(self, picker):
         """
         Private method to clear a path picker history.
