@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2008 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2008 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -13,12 +13,15 @@ ResourcesBrowserFlag = 4
 TranslationsBrowserFlag = 8
 InterfacesBrowserFlag = 16
 OthersBrowserFlag = 32
+ProtocolsBrowserFlag = 64
+
 AllBrowsersFlag = SourcesBrowserFlag | \
     FormsBrowserFlag | \
     ResourcesBrowserFlag | \
     TranslationsBrowserFlag | \
     InterfacesBrowserFlag | \
-    OthersBrowserFlag
+    OthersBrowserFlag | \
+    ProtocolsBrowserFlag
 
 #
 # eflag: noqa = M702
