@@ -215,7 +215,7 @@ class QuickFindFileDialog(QWidget, Ui_QuickFindFile):
         self.fileList.clear()
         locations = {}
 
-        for in_order, age, name in ordered:
+        for _in_order, _age, name in ordered:
             found = True
             QTreeWidgetItem(self.fileList, [os.path.basename(name),
                                             os.path.dirname(name)])
