@@ -47,10 +47,10 @@ class UserPropertiesDialog(QDialog, Ui_UserPropertiesDialog):
         enableVcsGroup = False
         if self.project.pdata["VCS"]:
             found = False
-            for indicator, vcsData in \
+            for _indicator, vcsData in \
                     e5App().getObject("PluginManager")\
                     .getVcsSystemIndicators().items():
-                for vcsSystem, vcsSystemDisplay in vcsData:
+                for vcsSystem, _vcsSystemDisplay in vcsData:
                     if vcsSystem == self.project.pdata["VCS"]:
                         found = True
                         break
