@@ -60,6 +60,7 @@ class EditorAssembly(QWidget):
         self.__membersCombo.activated[int].connect(self.__membersActivated)
         self.__editor.cursorLineChanged.connect(self.__editorCursorLineChanged)
         
+        self.__shutdownTimerCalled = False
         self.__parseTimer = QTimer(self)
         self.__parseTimer.setSingleShot(True)
         self.__parseTimer.setInterval(5 * 1000)
@@ -79,9 +80,11 @@ class EditorAssembly(QWidget):
         Public method to stop and disconnect the timer.
         """
         self.__parseTimer.stop()
-        self.__parseTimer.timeout.disconnect(self.__parseEditor)
-        self.__editor.textChanged.disconnect(self.__resetParseTimer)
-        self.__editor.refreshed.disconnect(self.__resetParseTimer)
+        if not self.__shutdownTimerCalled:
+            self.__parseTimer.timeout.disconnect(self.__parseEditor)
+            self.__editor.textChanged.disconnect(self.__resetParseTimer)
+            self.__editor.refreshed.disconnect(self.__resetParseTimer)
+            self.__shutdownTimerCalled = True
     
     def getEditor(self):
         """
@@ -198,7 +201,8 @@ class EditorAssembly(QWidget):
         if lineno is not None and moveCursor:
             txt = self.__editor.text(lineno - 1).rstrip()
             pos = len(txt.replace(txt.strip(), ""))
-            self.__editor.gotoLine(lineno, pos if pos == 0 else pos + 1, True)
+            self.__editor.gotoLine(lineno, pos if pos == 0 else pos + 1,
+                                   firstVisible=True, expand=True)
             self.__editor.setFocus()
     
     def __resetParseTimer(self):
