@@ -45,7 +45,7 @@ class ExporterODT(ExporterBase):
         QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
         QApplication.processEvents()
         
-        tabSize = Preferences.getEditor("TabWidth")
+        tabSize = self.editor.getEditorConfig("TabWidth")
         if tabSize == 0:
             tabSize = 4
         wysiwyg = Preferences.getEditorExporter("ODT/WYSIWYG")
