@@ -122,7 +122,7 @@ class ExporterTEX(ExporterBase):
             
             self.editor.recolor(0, -1)
             
-            tabSize = Preferences.getEditor("TabWidth")
+            tabSize = self.editor.getEditorConfig("TabWidth")
             if tabSize == 0:
                 tabSize = 4
             
