@@ -68,14 +68,17 @@ class BackgroundService(QTcpServer):
         ## Note: Need the port if started external in debugger:
         print('BackgroundService listening on: {0:d}'.format(port))
         # __IGNORE_WARNING__
-        for pyName in ['Python', 'Python3']:
-            interpreter = Preferences.getDebugger(
-                pyName + "Interpreter")
-            process = self.__startExternalClient(interpreter, port)
-            if process:
-                if pyName == 'Python':
-                    pyName = 'Python2'
-                self.processes[pyName] = process, interpreter
+        for pyName in ['Python2', 'Python3']:
+            venvName = Preferences.getDebugger(
+                pyName + "VirtualEnv")
+            interpreter = e5App().getObject("VirtualEnvManager")\
+                .getVirtualenvInterpreter(venvName)
+            if not interpreter and int(pyName[-1]) == sys.version_info[0]:
+                interpreter = sys.executable.replace("w.exe", ".exe")
+            if interpreter:
+                process = self.__startExternalClient(interpreter, port)
+                if process:
+                    self.processes[pyName] = process, interpreter
 
     def __startExternalClient(self, interpreter, port):
         """
@@ -246,12 +249,13 @@ class BackgroundService(QTcpServer):
         """
         Public slot to restart the built in languages.
         """
-        for pyName in ['Python', 'Python3']:
-            interpreter = Preferences.getDebugger(
-                pyName + "Interpreter")
-            
-            if pyName == 'Python':
-                pyName = 'Python2'
+        for pyName in ['Python2', 'Python3']:
+            venvName = Preferences.getDebugger(
+                pyName + "VirtualEnv")
+            interpreter = e5App().getObject("VirtualEnvManager")\
+                .getVirtualenvInterpreter(venvName)
+            if not interpreter and int(pyName[-1]) == sys.version_info[0]:
+                interpreter = sys.executable.replace("w.exe", ".exe")
             
             # Tweak the processes list to reflect the changed interpreter
             proc, inter = self.processes.pop(pyName, [None, None])
@@ -283,10 +287,11 @@ class BackgroundService(QTcpServer):
         if proc:
             proc.close()
         
-        port = self.serverPort()
-        process = self.__startExternalClient(interpreter, port)
-        if process:
-            self.processes[language] = process, interpreter
+        if interpreter:
+            port = self.serverPort()
+            process = self.__startExternalClient(interpreter, port)
+            if process:
+                self.processes[language] = process, interpreter
 
     def enqueueRequest(self, fx, lang, fn, data):
         """
@@ -419,8 +424,8 @@ class BackgroundService(QTcpServer):
             fx, lng, fn, data = self.runningJob
             if fx != 'INIT' and lng == lang:
                 self.services[(fx, lng)][3](fx, lng, fn, self.tr(
-                    'Erics background client disconnected because of an'
-                    ' unknown reason.')
+                    "Eric's background client disconnected because of an"
+                    " unknown reason.")
                 )
             self.isWorking = None
             
@@ -438,8 +443,10 @@ class BackgroundService(QTcpServer):
     def shutdown(self):
         """
         Public method to cleanup the connections and processes when eric is
-        shuting down.
+        shutting down.
         """
+        self.close()
+        
         for connection in self.connections.values():
             # Prevent calling of on_disconnectSocket
             connection.blockSignals(True)
