@@ -161,7 +161,7 @@ def readPlist(pathOrFile):
     try:
         reader = PlistReader(pathOrFile)
         result = reader.parse()
-    except NotBinaryPlistException as e:
+    except NotBinaryPlistException:
         try:
             pathOrFile.seek(0)
             result = plistlib.readPlist(pathOrFile)
