@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -10,7 +10,7 @@ systems.
 The general part of the VCS interface defines classes to implement common
 dialogs. These are a dialog to enter command options, a dialog to display
 some repository information and an abstract base class. The individual
-interfaces (i.e. CVS) have to be subclasses of this base class.
+interfaces have to be subclasses of this base class.
 """
 
 from __future__ import unicode_literals
@@ -40,23 +40,16 @@ def factory(vcs):
     if vc is None:
         # try alternative vcs interfaces assuming, that there is a common
         # indicator for the alternatives
-        found = False
-        for indicator, vcsData in \
-                pluginManager.getVcsSystemIndicators().items():
-            for vcsSystem, vcsSystemDisplay in vcsData:
-                if vcsSystem == vcs:
-                    found = True
-                    break
-            
-            if found:
-                if len(vcsData) > 1:
-                    for vcsSystem, vcsSystemDisplay in vcsData:
+        for vcsData in pluginManager.getVcsSystemIndicators().values():
+            for vcsSystem, _vcsSystemDisplay in vcsData:
+                if vcsSystem == vcs and len(vcsData) > 1:
+                    for vcsSystem, _vcsSystemDisplay in vcsData:
                         if vcsSystem != vcs:
                             vc = pluginManager.getPluginObject(
                                 "version_control", vcsSystem, maybeActive=True)
                             if vc is not None:
-                                break
-                break
+                                return vc
+    
     return vc
 
 
