@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -59,6 +59,11 @@ class CookieJar(QNetworkCookieJar):
                                           "web_browser", "cookies.ini")
         
         self.__store = WebBrowserWindow.webProfile().cookieStore()
+        try:
+            self.__store.setCookieFilter(self.__cookieFilter)
+        except AttributeError:
+            # pre Qt 5.11
+            pass
         self.__store.cookieAdded.connect(self.__cookieAdded)
         self.__store.cookieRemoved.connect(self.__cookieRemoved)
         
@@ -187,6 +192,38 @@ class CookieJar(QNetworkCookieJar):
         if self.deleteCookie(cookie):
             self.cookiesChanged.emit()
     
+    def __cookieFilter(self, request):
+        """
+        Private method to filter cookies.
+        
+        Note: This method is used for Qt 5.11+ only.
+        
+        @param request reference to the cookie filter request object
+        @type QWebEngineCookieStore.FilterRequest
+        @return flag indicating cookie access is allowed
+        @rtype bool
+        """
+        if not self.__loaded:
+            self.__load()
+        
+        if self.__acceptCookies == self.AcceptNever:
+            res = self.__isOnDomainList(self.__exceptionsAllow,
+                                        request.origin.host())
+            if not res:
+                return False
+        
+        if self.__acceptCookies == self.AcceptAlways:
+            res = self.__isOnDomainList(self.__exceptionsBlock,
+                                        request.origin.host())
+            if res:
+                return False
+        
+        if self.__acceptCookies == self.AcceptOnlyFromSitesNavigatedTo and \
+           request.thirdParty:
+            return False
+        
+        return True
+ 
     def __rejectCookie(self, cookie, cookieDomain):
         """
         Private method to test, if a cookie shall be rejected.
@@ -214,14 +251,16 @@ class CookieJar(QNetworkCookieJar):
         if self.__acceptCookies == self.AcceptOnlyFromSitesNavigatedTo:
             mainWindow = WebBrowserWindow.mainWindow()
             if mainWindow is not None:
-                url = mainWindow.getWindow().currentBrowser().url()
-                if url.isValid():
-                    host = url.host()
-                else:
-                    host = ""
-                res = self.__matchDomain(cookieDomain, host)
-                if not res:
-                    return True
+                browser = mainWindow.getWindow().currentBrowser()
+                if browser is not None:
+                    url = browser.url()
+                    if url.isValid():
+                        host = url.host()
+                    else:
+                        host = ""
+                    res = self.__matchDomain(cookieDomain, host)
+                    if not res:
+                        return True
         
         if self.__filterTrackingCookies and cookie.name().startsWith(b"__utm"):
             return True
