@@ -91,7 +91,7 @@ class GreaseMonkeyDownloader(QObject):
         
         try:
             f = open(self.__fileName, "w", encoding="utf-8")
-        except (IOError, OSError) as err:
+        except (IOError, OSError):
             self.error.emit()
             return
         f.write(response)
@@ -145,7 +145,7 @@ class GreaseMonkeyDownloader(QObject):
         
         try:
             f = open(self.__fileName, "w", encoding="utf-8")
-        except (IOError, OSError) as err:
+        except (IOError, OSError):
             self.error.emit()
             return
         f.write(response)
