@@ -16,9 +16,9 @@ except NameError:
 
 import os
 
-from PyQt5.QtCore import pyqtSignal, PYQT_VERSION, Qt, QUrl, QFileInfo, \
-    QTimer, QEvent, QPoint, QPointF, QDateTime, QStandardPaths, QByteArray, \
-    QIODevice, QDataStream
+from PyQt5.QtCore import pyqtSignal, pyqtSlot, PYQT_VERSION, Qt, QUrl, \
+    QFileInfo, QTimer, QEvent, QPoint, QPointF, QDateTime, QStandardPaths, \
+    QByteArray, QIODevice, QDataStream
 from PyQt5.QtGui import QDesktopServices, QClipboard, QIcon, \
     QContextMenuEvent, QPixmap
 from PyQt5.QtWidgets import qApp, QStyle, QMenu, QApplication
@@ -95,6 +95,7 @@ class WebBrowserView(QWebEngineView):
         self.__createNewPage()
         
         self.__mw = mainWindow
+        self.__tabWidget = parent
         self.__isLoading = False
         self.__progress = 0
         self.__siteIconLoader = None
@@ -135,7 +136,8 @@ class WebBrowserView(QWebEngineView):
         if qVersionTuple() >= (5, 8, 0):
             if self.parentWidget() is not None:
                 self.parentWidget().installEventFilter(self)
-            
+        
+        if qVersionTuple() >= (5, 8, 0) and qVersionTuple() < (5, 11, 0):
             lay = self.layout()
             lay.currentChanged.connect(
                 lambda: QTimer.singleShot(0, self.__setRwhvqt))
@@ -152,6 +154,14 @@ class WebBrowserView(QWebEngineView):
         
         self.__page.safeBrowsingAbort.connect(self.safeBrowsingAbort)
         self.__page.safeBrowsingBad.connect(self.safeBrowsingBad)
+        self.__page.printRequested.connect(self.__printPage)
+        try:
+            self.__page.quotaRequested.connect(self.__quotaRequested)
+            self.__page.registerProtocolHandlerRequested.connect(
+                self.__registerProtocolHandlerRequested)
+        except AttributeError:
+            # pre Qt 5.11
+            pass
     
     def __setRwhvqt(self):
         """
@@ -181,6 +191,16 @@ class WebBrowserView(QWebEngineView):
         """
         return self.__mw
     
+    def tabWidget(self):
+        """
+        Public method to get a reference to the tab widget containing this
+        view.
+        
+        @return reference to the tab widget
+        @rtype WebBrowserTabWidget
+        """
+        return self.__tabWidget
+    
     def load(self, url):
         """
         Public method to load a web site.
@@ -188,6 +208,11 @@ class WebBrowserView(QWebEngineView):
         @param url URL to be loaded
         @type QUrl
         """
+        if self.__page is not None and \
+            not self.__page.acceptNavigationRequest(
+                url, QWebEnginePage.NavigationTypeTyped, True):
+            return
+        
         super(WebBrowserView, self).load(url)
         
         if not self.__firstLoad:
@@ -526,7 +551,8 @@ class WebBrowserView(QWebEngineView):
             self.__menu.addSeparator()
             self.__menu.addAction(self.__mw.adBlockIcon().menuAction())
         
-        if Preferences.getWebBrowser("WebInspectorEnabled"):
+        if qVersionTuple() >= (5, 11, 0) or \
+           Preferences.getWebBrowser("WebInspectorEnabled"):
             self.__menu.addSeparator()
             self.__menu.addAction(
                 UI.PixmapCache.getIcon("webInspector.png"),
@@ -556,10 +582,10 @@ class WebBrowserView(QWebEngineView):
                 boldFont.setBold(True)
                 
                 for suggestion in contextMenuData.spellCheckerSuggestions():
-                    act = menu.addAction(
-                        suggestion,
-                        self.__replaceMisspelledWord)
+                    act = menu.addAction(suggestion)
                     act.setFont(boldFont)
+                    act.triggered.connect(
+                        lambda: self.__replaceMisspelledWord)(act)
                 
                 if not bool(menu.actions()):
                     menu.addAction(self.tr("No suggestions")).setEnabled(False)
@@ -614,41 +640,55 @@ class WebBrowserView(QWebEngineView):
         if not menu.isEmpty():
             menu.addSeparator()
         
-        menu.addAction(
+        act = menu.addAction(
             UI.PixmapCache.getIcon("openNewTab.png"),
-            self.tr("Open Link in New Tab\tCtrl+LMB"),
-            self.__openLinkInNewTab).setData(hitTest.linkUrl())
-        menu.addAction(
+            self.tr("Open Link in New Tab\tCtrl+LMB"))
+        act.setData(hitTest.linkUrl())
+        act.triggered.connect(
+            lambda: self.__openLinkInNewTab(act))
+        act = menu.addAction(
             UI.PixmapCache.getIcon("newWindow.png"),
-            self.tr("Open Link in New Window"),
-            self.__openLinkInNewWindow).setData(hitTest.linkUrl())
-        menu.addAction(
+            self.tr("Open Link in New Window"))
+        act.setData(hitTest.linkUrl())
+        act.triggered.connect(
+            lambda: self.__openLinkInNewWindow(act))
+        act = menu.addAction(
             UI.PixmapCache.getIcon("privateMode.png"),
-            self.tr("Open Link in New Private Window"),
-            self.__openLinkInNewPrivateWindow).setData(hitTest.linkUrl())
+            self.tr("Open Link in New Private Window"))
+        act.setData(hitTest.linkUrl())
+        act.triggered.connect(
+            lambda: self.__openLinkInNewPrivateWindow(act))
         menu.addSeparator()
         menu.addAction(
             UI.PixmapCache.getIcon("download.png"),
             self.tr("Save Lin&k"), self.__downloadLink)
-        menu.addAction(
+        act = menu.addAction(
             UI.PixmapCache.getIcon("bookmark22.png"),
-            self.tr("Bookmark this Link"), self.__bookmarkLink)\
-            .setData(hitTest.linkUrl())
+            self.tr("Bookmark this Link"))
+        act.setData(hitTest.linkUrl())
+        act.triggered.connect(
+            lambda: self.__bookmarkLink(act))
         menu.addSeparator()
-        menu.addAction(
+        act = menu.addAction(
             UI.PixmapCache.getIcon("editCopy.png"),
-            self.tr("Copy Link to Clipboard"), self.__copyLink)\
-            .setData(hitTest.linkUrl())
-        menu.addAction(
+            self.tr("Copy Link to Clipboard"))
+        act.setData(hitTest.linkUrl())
+        act.triggered.connect(
+            lambda: self.__copyLink(act))
+        act = menu.addAction(
             UI.PixmapCache.getIcon("mailSend.png"),
-            self.tr("Send Link"),
-            self.__sendLink).setData(hitTest.linkUrl())
+            self.tr("Send Link"))
+        act.setData(hitTest.linkUrl())
+        act.triggered.connect(
+            lambda: self.__sendLink(act))
         if Preferences.getWebBrowser("VirusTotalEnabled") and \
            Preferences.getWebBrowser("VirusTotalServiceKey") != "":
-            menu.addAction(
+            act = menu.addAction(
                 UI.PixmapCache.getIcon("virustotal.png"),
-                self.tr("Scan Link with VirusTotal"),
-                self.__virusTotal).setData(hitTest.linkUrl())
+                self.tr("Scan Link with VirusTotal"))
+            act.setData(hitTest.linkUrl())
+            act.triggered.connect(
+                lambda: self.__virusTotal(act))
         
     def __createImageContextMenu(self, menu, hitTest):
         """
@@ -662,57 +702,69 @@ class WebBrowserView(QWebEngineView):
         if not menu.isEmpty():
             menu.addSeparator()
         
-        menu.addAction(
+        act = menu.addAction(
             UI.PixmapCache.getIcon("openNewTab.png"),
-            self.tr("Open Image in New Tab"),
-            self.__openLinkInNewTab).setData(hitTest.imageUrl())
+            self.tr("Open Image in New Tab"))
+        act.setData(hitTest.imageUrl())
+        act.triggered.connect(
+            lambda: self.__openLinkInNewTab(act))
         menu.addSeparator()
         menu.addAction(
             UI.PixmapCache.getIcon("download.png"),
             self.tr("Save Image"), self.__downloadImage)
         menu.addAction(
             self.tr("Copy Image to Clipboard"), self.__copyImage)
-        menu.addAction(
+        act = menu.addAction(
             UI.PixmapCache.getIcon("editCopy.png"),
-            self.tr("Copy Image Location to Clipboard"),
-            self.__copyLink).setData(hitTest.imageUrl())
-        menu.addAction(
+            self.tr("Copy Image Location to Clipboard"))
+        act.setData(hitTest.imageUrl())
+        act.triggered.connect(
+            lambda: self.__copyLink(act))
+        act = menu.addAction(
             UI.PixmapCache.getIcon("mailSend.png"),
-            self.tr("Send Image Link"),
-            self.__sendLink).setData(hitTest.imageUrl())
+            self.tr("Send Image Link"))
+        act.setData(hitTest.imageUrl())
+        act.triggered.connect(
+            lambda: self.__sendLink(act))
         
         if hitTest.imageUrl().scheme() in ["http", "https"]:
             menu.addSeparator()
             engine = WebBrowserWindow.imageSearchEngine()
             searchEngineName = engine.searchEngine()
-            menu.addAction(
+            act = menu.addAction(
                 UI.PixmapCache.getIcon("{0}.png".format(
                     searchEngineName.lower())),
-                self.tr("Search image in {0}").format(searchEngineName),
-                self.__searchImage).setData(
-                    engine.getSearchQuery(hitTest.imageUrl()))
+                self.tr("Search image in {0}").format(searchEngineName))
+            act.setData(engine.getSearchQuery(hitTest.imageUrl()))
+            act.triggered.connect(
+                lambda: self.__searchImage(act))
             self.__imageSearchMenu = menu.addMenu(
                 self.tr("Search image with..."))
             for searchEngineName in engine.searchEngineNames():
-                self.__imageSearchMenu.addAction(
+                act = self.__imageSearchMenu.addAction(
                     UI.PixmapCache.getIcon("{0}.png".format(
                         searchEngineName.lower())),
-                    self.tr("Search image in {0}").format(searchEngineName),
-                    self.__searchImage).setData(
-                        engine.getSearchQuery(
-                            hitTest.imageUrl(), searchEngineName))
+                    self.tr("Search image in {0}").format(searchEngineName))
+                act.setData(engine.getSearchQuery(
+                    hitTest.imageUrl(), searchEngineName))
+                act.triggered.connect(
+                    lambda: self.__searchImage(act))
         
         menu.addSeparator()
-        menu.addAction(
+        act = menu.addAction(
             UI.PixmapCache.getIcon("adBlockPlus.png"),
-            self.tr("Block Image"), self.__blockImage)\
-            .setData(hitTest.imageUrl().toString())
+            self.tr("Block Image"))
+        act.setData(hitTest.imageUrl().toString())
+        act.triggered.connect(
+            lambda: self.__blockImage(act))
         if Preferences.getWebBrowser("VirusTotalEnabled") and \
            Preferences.getWebBrowser("VirusTotalServiceKey") != "":
-            menu.addAction(
+            act = menu.addAction(
                 UI.PixmapCache.getIcon("virustotal.png"),
-                self.tr("Scan Image with VirusTotal"),
-                self.__virusTotal).setData(hitTest.imageUrl())
+                self.tr("Scan Image with VirusTotal"))
+            act.setData(hitTest.imageUrl())
+            act.triggered.connect(
+                lambda: self.__virusTotal(act))
     
     def __createMediaContextMenu(self, menu, hitTest):
         """
@@ -743,14 +795,18 @@ class WebBrowserView(QWebEngineView):
                 UI.PixmapCache.getIcon("audioVolumeMuted.png"),
                 self.tr("Mute"), self.__muteMedia)
         menu.addSeparator()
-        menu.addAction(
+        act = menu.addAction(
             UI.PixmapCache.getIcon("editCopy.png"),
-            self.tr("Copy Media Address to Clipboard"),
-            self.__copyLink).setData(hitTest.mediaUrl())
-        menu.addAction(
+            self.tr("Copy Media Address to Clipboard"))
+        act.setData(hitTest.mediaUrl())
+        act.triggered.connect(
+            lambda: self.__copyLink(act))
+        act = menu.addAction(
             UI.PixmapCache.getIcon("mailSend.png"),
-            self.tr("Send Media Address"), self.__sendLink)\
-            .setData(hitTest.mediaUrl())
+            self.tr("Send Media Address"))
+        act.setData(hitTest.mediaUrl())
+        act.triggered.connect(
+            lambda: self.__sendLink(act))
         menu.addAction(
             UI.PixmapCache.getIcon("download.png"),
             self.tr("Save Media"), self.__downloadMedia)
@@ -769,10 +825,12 @@ class WebBrowserView(QWebEngineView):
         
         menu.addAction(self.__mw.copyAct)
         menu.addSeparator()
-        menu.addAction(
+        act = menu.addAction(
             UI.PixmapCache.getIcon("mailSend.png"),
-            self.tr("Send Text"),
-            self.__sendLink).setData(self.selectedText())
+            self.tr("Send Text"))
+        act.setData(self.selectedText())
+        act.triggered.connect(
+            lambda: self.__sendLink(act))
         
         engineName = self.__mw.openSearchManager().currentEngineName()
         if engineName:
@@ -804,24 +862,29 @@ class WebBrowserView(QWebEngineView):
             googleTranslatorUrl = QUrl(
                 "http://translate.google.com/#auto/{0}/{1}".format(
                     langCode, self.selectedText()))
-            menu.addAction(
+            act = menu.addAction(
                 UI.PixmapCache.getIcon("translate.png"),
-                self.tr("Google Translate"), self.__openLinkInNewTab)\
-                .setData(googleTranslatorUrl)
+                self.tr("Google Translate"))
+            act.setData(googleTranslatorUrl)
+            act.triggered.connect(
+                lambda: self.__openLinkInNewTab(act))
             wiktionaryUrl = QUrl(
                 "http://{0}.wiktionary.org/wiki/Special:Search?search={1}"
                 .format(langCode, self.selectedText()))
-            menu.addAction(
+            act = menu.addAction(
                 UI.PixmapCache.getIcon("wikipedia.png"),
-                self.tr("Dictionary"), self.__openLinkInNewTab)\
-                .setData(wiktionaryUrl)
+                self.tr("Dictionary"))
+            act.setData(wiktionaryUrl)
+            act.triggered.connect(
+                lambda: self.__openLinkInNewTab(act))
             menu.addSeparator()
         
         guessedUrl = QUrl.fromUserInput(self.selectedText().strip())
         if self.__isUrlValid(guessedUrl):
-            menu.addAction(
-                self.tr("Go to web address"),
-                self.__openLinkInNewTab).setData(guessedUrl)
+            act = menu.addAction(self.tr("Go to web address"))
+            act.setData(guessedUrl)
+            act.triggered.connect(
+                lambda: self.__openLinkInNewTab(act))
     
     def __createPageContextMenu(self, menu):
         """
@@ -835,7 +898,8 @@ class WebBrowserView(QWebEngineView):
         menu.addSeparator()
         if self.__mw.saveAsAct is not None:
             menu.addAction(self.__mw.saveAsAct)
-            menu.addSeparator()
+        menu.addAction(self.__mw.saveVisiblePageScreenAct)
+        menu.addSeparator()
         
         if self.url().toString() == "eric:speeddial":
             # special menu for the spedd dial page
@@ -860,12 +924,18 @@ class WebBrowserView(QWebEngineView):
         menu.addAction(
             UI.PixmapCache.getIcon("bookmark22.png"),
             self.tr("Bookmark this Page"), self.addBookmark)
-        menu.addAction(
+        act = menu.addAction(
             UI.PixmapCache.getIcon("editCopy.png"),
-            self.tr("Copy Page Link"), self.__copyLink).setData(self.url())
-        menu.addAction(
+            self.tr("Copy Page Link"))
+        act.setData(self.url())
+        act.triggered.connect(
+            lambda: self.__copyLink(act))
+        act = menu.addAction(
             UI.PixmapCache.getIcon("mailSend.png"),
-            self.tr("Send Page Link"), self.__sendLink).setData(self.url())
+            self.tr("Send Page Link"))
+        act.setData(self.url())
+        act.triggered.connect(
+            lambda: self.__sendLink(act))
         menu.addSeparator()
         
         from .UserAgent.UserAgentMenu import UserAgentMenu
@@ -896,10 +966,12 @@ class WebBrowserView(QWebEngineView):
             w3url = QUrl.fromEncoded(
                 b"http://validator.w3.org/check?uri=" +
                 QUrl.toPercentEncoding(bytes(self.url().toEncoded()).decode()))
-            menu.addAction(
+            act = menu.addAction(
                 UI.PixmapCache.getIcon("w3.png"),
-                self.tr("Validate Page"), self.__openLinkInNewTab)\
-                .setData(w3url)
+                self.tr("Validate Page"))
+            act.setData(w3url)
+            act.triggered.connect(
+                lambda: self.__openLinkInNewTab(act))
             
             from .WebBrowserLanguagesDialog import WebBrowserLanguagesDialog
             languages = Preferences.toList(
@@ -915,11 +987,13 @@ class WebBrowserView(QWebEngineView):
                     b"&u=" +
                     QUrl.toPercentEncoding(
                         bytes(self.url().toEncoded()).decode()))
-                menu.addAction(
+                act = menu.addAction(
                     UI.PixmapCache.getIcon("translate.png"),
-                    self.tr("Google Translate"), self.__openLinkInNewTab)\
-                    .setData(googleTranslatorUrl)
-        
+                    self.tr("Google Translate"))
+                act.setData(googleTranslatorUrl)
+            act.triggered.connect(
+                lambda: self.__openLinkInNewTab(act))
+    
     def __checkForForm(self, act, pos):
         """
         Private method to check the given position for an open search form.
@@ -970,55 +1044,65 @@ class WebBrowserView(QWebEngineView):
             bool(url.scheme()) and \
             "." in url.host()
     
-    def __replaceMisspelledWord(self):
+    def __replaceMisspelledWord(self, act):
         """
         Private slot to replace a misspelled word under the context menu.
+        
+        @param act reference to the action that triggered
+        @type QAction
         """
-        act = self.sender()
         suggestion = act.text()
         self.page().replaceMisspelledWord(suggestion)
     
-    def __openLinkInNewTab(self):
+    def __openLinkInNewTab(self, act):
         """
         Private method called by the context menu to open a link in a new
         tab.
+        
+        @param act reference to the action that triggered
+        @type QAction
         """
-        act = self.sender()
         url = act.data()
         if url.isEmpty():
             return
         
         self.setSource(url, newTab=True)
     
-    def __openLinkInNewWindow(self):
+    def __openLinkInNewWindow(self, act):
         """
         Private slot called by the context menu to open a link in a new
         window.
+        
+        @param act reference to the action that triggered
+        @type QAction
         """
-        act = self.sender()
         url = act.data()
         if url.isEmpty():
             return
         
         self.__mw.newWindow(url)
     
-    def __openLinkInNewPrivateWindow(self):
+    def __openLinkInNewPrivateWindow(self, act):
         """
         Private slot called by the context menu to open a link in a new
         private window.
+        
+        @param act reference to the action that triggered
+        @type QAction
         """
-        act = self.sender()
         url = act.data()
         if url.isEmpty():
             return
         
         self.__mw.newPrivateWindow(url)
     
-    def __bookmarkLink(self):
+    def __bookmarkLink(self, act):
         """
         Private slot to bookmark a link via the context menu.
+        
+        @param act reference to the action that triggered
+        @type QAction
         """
-        act = self.sender()
         url = act.data()
         if url.isEmpty():
             return
@@ -1028,11 +1112,13 @@ class WebBrowserView(QWebEngineView):
         dlg.setUrl(bytes(url.toEncoded()).decode())
         dlg.exec_()
     
-    def __sendLink(self):
+    def __sendLink(self, act):
         """
         Private slot to send a link via email.
+        
+        @param act reference to the action that triggered
+        @type QAction
         """
-        act = self.sender()
         data = act.data()
         if isinstance(data, QUrl) and data.isEmpty():
             return
@@ -1041,11 +1127,13 @@ class WebBrowserView(QWebEngineView):
             data = data.toString()
         QDesktopServices.openUrl(QUrl("mailto:?body=" + data))
     
-    def __copyLink(self):
+    def __copyLink(self, act):
         """
         Private slot to copy a link to the clipboard.
+        
+        @param act reference to the action that triggered
+        @type QAction
         """
-        act = self.sender()
         data = act.data()
         if isinstance(data, QUrl) and data.isEmpty():
             return
@@ -1072,20 +1160,24 @@ class WebBrowserView(QWebEngineView):
         """
         self.triggerPageAction(QWebEnginePage.CopyImageToClipboard)
     
-    def __blockImage(self):
+    def __blockImage(self, act):
         """
         Private slot to add a block rule for an image URL.
+        
+        @param act reference to the action that triggered
+        @type QAction
         """
-        act = self.sender()
         url = act.data()
         dlg = WebBrowserWindow.adBlockManager().showDialog()
         dlg.addCustomRule(url)
     
-    def __searchImage(self):
+    def __searchImage(self, act):
         """
         Private slot to search for an image URL.
+        
+        @param act reference to the action that triggered
+        @type QAction
         """
-        act = self.sender()
         url = act.data()
         self.setSource(url, newTab=True)
     
@@ -1107,11 +1199,13 @@ class WebBrowserView(QWebEngineView):
         """
         self.triggerPageAction(QWebEnginePage.ToggleMediaMute)
     
-    def __virusTotal(self):
+    def __virusTotal(self, act):
         """
         Private slot to scan the selected URL with VirusTotal.
+        
+        @param act reference to the action that triggered
+        @type QAction
         """
-        act = self.sender()
         url = act.data()
         self.__mw.requestVirusTotalScan(url)
     
@@ -1163,13 +1257,16 @@ class WebBrowserView(QWebEngineView):
         """
         Private slot to show the web inspector window.
         """
-        if self.__inspector is None:
-            from .WebInspector import WebInspector
-            self.__inspector = WebInspector()
-            self.__inspector.setView(self, True)
-            self.__inspector.show()
-        else:
-            self.closeWebInspector()
+        from .WebInspector import WebInspector
+        if WebInspector.isEnabled():
+            if self.__inspector is None:
+                self.__inspector = WebInspector()
+                self.__inspector.setView(self, True)
+                self.__inspector.inspectorClosed.connect(
+                    self.closeWebInspector)
+                self.__inspector.show()
+            else:
+                self.closeWebInspector()
     
     def closeWebInspector(self):
         """
@@ -1411,6 +1508,10 @@ class WebBrowserView(QWebEngineView):
         @return flag indicating that the event should be filtered out
         @rtype bool
         """
+        if obj is self and evt.type() == QEvent.ParentChange and \
+           self.parentWidget() is not None:
+            self.parentWidget().installEventFilter(self)
+        
         # find the render widget receiving events for the web page
         if qVersionTuple() < (5, 8, 0):
             if obj is self and evt.type() == QEvent.ChildAdded:
@@ -1422,10 +1523,9 @@ class WebBrowserView(QWebEngineView):
                     self.grabGesture(Qt.PinchGesture)
                     self.__rwhvqt.grabGesture(Qt.PinchGesture)
                     self.__rwhvqt.installEventFilter(self)
-        else:
-            if obj is self and evt.type() == QEvent.ParentChange and \
-               self.parentWidget() is not None:
-                self.parentWidget().installEventFilter(self)
+        elif qVersionTuple() >= (5, 11, 0):
+            if obj is self and evt.type() == QEvent.ChildAdded:
+                QTimer.singleShot(0, self.__setRwhvqt)
         
         # forward events to WebBrowserView
         if obj is self.__rwhvqt and \
@@ -1562,6 +1662,29 @@ class WebBrowserView(QWebEngineView):
         from .Tools import WebIconProvider
         return WebIconProvider.instance().iconForUrl(self.url())
     
+    def title(self):
+        """
+        Public method to get the view title.
+        
+        @return view title
+        @rtype str
+        """
+        titleStr = super(WebBrowserView, self).title()
+        if not titleStr:
+            if self.url().isEmpty():
+                url = self.__page.requestedUrl()
+            else:
+                url = self.url()
+            
+            titleStr = url.host()
+            if not titleStr:
+                titleStr = url.toString(QUrl.RemoveFragment)
+            
+        if not titleStr or titleStr == "about:blank":
+            titleStr = self.tr("Empty Page")
+        
+        return titleStr
+    
     def __linkHovered(self, link):
         """
         Private slot to handle the linkHovered signal.
@@ -2081,3 +2204,85 @@ class WebBrowserView(QWebEngineView):
             return self.__page.getSafeBrowsingStatus()
         else:
             return True
+    
+    ###########################################################################
+    ## Methods below implement print support from the page
+    ###########################################################################
+    
+    @pyqtSlot()
+    def __printPage(self):
+        """
+        Private slot to support printing from the web page.
+        """
+        self.__mw.tabWidget.printBrowser(browser=self)
+    
+    ###########################################################################
+    ## Methods below implement slots for Qt 5.11+
+    ###########################################################################
+    
+    if qVersionTuple() >= (5, 11, 0):
+        @pyqtSlot("QWebEngineQuotaRequest")
+        def __quotaRequested(self, quotaRequest):
+            """
+            Private slot to handle quota requests of the web page.
+            
+            @param quotaRequest reference to the quota request object
+            @type QWebEngineQuotaRequest
+            """
+            acceptRequest = Preferences.getWebBrowser("AcceptQuotaRequest")
+            # yes/no/ask (0, 1, 2)
+            if acceptRequest == 0:
+                # always yes
+                ok = True
+            elif acceptRequest == 1:
+                # always no
+                ok = False
+            else:
+                # ask user
+                from .Download.DownloadUtilities import dataString
+                sizeStr = dataString(quotaRequest.requestedSize())
+                
+                ok = E5MessageBox.yesNo(
+                    self,
+                    self.tr("Quota Request"),
+                    self.tr("""<p> Allow the website at <b>{0}</b> to use"""
+                            """ <b>{1}</b> of persistent storage?</p>""")
+                    .format(quotaRequest.origin().host(), sizeStr)
+                )
+            
+            if ok:
+                quotaRequest.accept()
+            else:
+                quotaRequest.reject()
+        
+        @pyqtSlot("QWebEngineRegisterProtocolHandlerRequest")
+        def __registerProtocolHandlerRequested(self, request):
+            """
+            Private slot to handle requests for registration of a protocol handler.
+            
+            @param request reference to the protocol handler request object
+            @type QWebEngineRegisterProtocolHandlerRequest
+            """
+            acceptRequest = Preferences.getWebBrowser(
+                "AcceptProtocolHandlerRequest")
+            # yes/no/ask (0, 1, 2)
+            if acceptRequest == 0:
+                # always yes
+                ok = True
+            elif acceptRequest == 1:
+                # always no
+                ok = False
+            else:
+                # ask user
+                ok = E5MessageBox.yesNo(
+                    self,
+                    self.tr("Protocol Handler Request"),
+                    self.tr("""<p> Allow the website at <b>{0}</b> to open all"""
+                            """ <b>{1}</b> links?</p>""")
+                    .format(request.origin().host(), request.scheme())
+                )
+            
+            if ok:
+                request.accept()
+            else:
+                request.reject()
