@@ -21,6 +21,8 @@ from PyQt5.QtNetwork import QNetworkRequest
 from PyQt5.QtWebEngineWidgets import QWebEngineView, QWebEnginePage, \
     QWebEngineSettings
 
+from Globals import qVersionTuple
+
 import Preferences
 
 _VIEWS = []
@@ -93,18 +95,23 @@ class WebInspector(QWebEngineView):
         
         self.__inspectElement = inspectElement
         
-        port = Preferences.getWebBrowser("WebInspectorPort")
-        inspectorUrl = QUrl("http://localhost:{0}".format(port))
-        
-        from WebBrowser.WebBrowserWindow import WebBrowserWindow
-        self.__reply = WebBrowserWindow.networkManager().get(
-            QNetworkRequest(inspectorUrl.resolved(QUrl("json/list"))))
-        self.__reply.finished.connect(self.__inspectorReplyFinished)
+        try:
+            self.page().setInspectedPage(self.__view.page())
+        except AttributeError:
+            # pre Qt 5.11
+            port = Preferences.getWebBrowser("WebInspectorPort")
+            inspectorUrl = QUrl("http://localhost:{0}".format(port))
+            
+            from WebBrowser.WebBrowserWindow import WebBrowserWindow
+            self.__reply = WebBrowserWindow.networkManager().get(
+                QNetworkRequest(inspectorUrl.resolved(QUrl("json/list"))))
+            self.__reply.finished.connect(self.__inspectorReplyFinished)
     
     def __inspectorReplyFinished(self):
         """
         Private slot handling the reply.
         """
+        # used for pre Qt 5.11
         result = str(self.__reply.readAll(), encoding="utf8")
         
         self.__reply.deleteLater()
@@ -145,15 +152,19 @@ class WebInspector(QWebEngineView):
         @return flag indicating the enabled state
         @rtype bool
         """
-        if not os.getenv("QTWEBENGINE_REMOTE_DEBUGGING"):
-            return False
+        if qVersionTuple() < (5, 11, 0):
+            if not os.getenv("QTWEBENGINE_REMOTE_DEBUGGING"):
+                return False
         
         from WebBrowser.WebBrowserWindow import WebBrowserWindow
         if not WebBrowserWindow.webSettings().testAttribute(
                 QWebEngineSettings.JavascriptEnabled):
             return False
         
-        return Preferences.getWebBrowser("WebInspectorEnabled")
+        if qVersionTuple() < (5, 11, 0):
+            return Preferences.getWebBrowser("WebInspectorEnabled")
+        else:
+            return True
     
     def __loadFinished(self):
         """
