@@ -132,12 +132,8 @@ def main():
     except getopt.error:
         usage()
 
-    excludeDirs = ["CVS", ".svn", "_svn",
-                   ".ropeproject", "_ropeproject",
-                   ".eric5project", "_eric5project",
-                   ".eric6project", "_eric6project",
-                   "dist", "build", "doc", "docs"
-                   ]
+    excludeDirs = [".svn", ".hg", ".git", ".ropeproject", ".eric6project",
+                   "dist", "build", "doc", "docs"]
     excludePatterns = []
     outputFileName = ""
     recursive = False
