@@ -22,7 +22,10 @@ except (ImportError):
     pass
 
 try:
-    import sip
+    try:
+        from PyQt5 import sip
+    except ImportError:
+        import sip
     sip.setdestroyonexit(False)
 except AttributeError:
     pass
