@@ -13,7 +13,10 @@ from __future__ import unicode_literals, print_function
 try:
     # Python2 only
     import cStringIO as io
-    import sip
+    try:
+        from PyQt5 import sip
+    except ImportError:
+        import sip
     sip.setapi('QString', 2)
     sip.setapi('QVariant', 2)
     sip.setapi('QTextStream', 2)
@@ -1242,7 +1245,10 @@ def pipInstall(packageName, message):
     ok = False
     print("{0}\n\nShall '{1}' be installed using pip? (Y/n)"
           .format(message, packageName), end=" ")
-    answer = input()
+    if sys.version_info[0] == 2:
+        answer = raw_input()        # __IGNORE_WARNING__
+    else:
+        answer = input()
     if answer in ("", "Y", "y"):
         exitCode = subprocess.call(
             [sys.executable, "-m", "pip", "install", packageName])
@@ -1272,7 +1278,7 @@ def doDependancyChecks():
     
     try:
         import xml.etree            # __IGNORE_WARNING__
-    except ImportError as msg:
+    except ImportError:
         print('Your Python installation is missing the XML module.')
         print('Please install it and try again.')
         exit(5)
@@ -1289,10 +1295,14 @@ def doDependancyChecks():
         try:
             from PyQt5.QtCore import qVersion
         except ImportError as msg:
-            installed = pipInstall(
-                "PyQt5",
-                "PyQt5 could not be detected.\nError: {0}".format(msg)
-            )
+            if sys.version_info[0] == 2:
+                # no PyQt5 wheels available for Python 2
+                installed = False
+            else:
+                installed = pipInstall(
+                    "PyQt5",
+                    "PyQt5 could not be detected.\nError: {0}".format(msg)
+                )
             if installed:
                 # try to import it again
                 try:
@@ -1302,6 +1312,8 @@ def doDependancyChecks():
                     print('Error: {0}'.format(msg))
                     exit(1)
             else:
+                print('Sorry, please install PyQt5.')
+                print('Error: {0}'.format(msg))
                 exit(1)
         print("Found PyQt5")
     
@@ -1338,10 +1350,12 @@ def doDependancyChecks():
                     message = None
                 except ImportError as msg:
                     message = str(msg)
+            else:
+                message = "QScintilla could not be installed."
         if message:
             print("Sorry, please install QScintilla2 and")
             print("its PyQt5/PyQt4 wrapper.")
-            print('Error: {0}'.format(msg))
+            print('Error: {0}'.format(message))
             exit(1)
     print("Found QScintilla2")
     
@@ -1414,7 +1428,10 @@ def doDependancyChecks():
     
     # check version of sip
     try:
-        import sip
+        try:
+            from PyQt5 import sip
+        except ImportError:
+            import sip
         sipVersion = sip.SIP_VERSION_STR
         print("sip Version:", sipVersion.strip())
         # always assume, that snapshots or dev versions are new enough
