@@ -28,11 +28,13 @@ def getConfig(name):
     '''
     Module function to get a configuration value.
 
-    @param name name of the configuration value (string)
+    @param name name of the configuration value    @type str
+    @exception AttributeError raised to indicate an invalid config entry
     '''
     try:
         return _pkg_config[name]
     except KeyError:
         pass
 
-    raise AttributeError('"{0}" is not a valid configuration value'.format(name))
+    raise AttributeError(
+        '"{0}" is not a valid configuration value'.format(name))
